@@ -167,6 +167,10 @@
 #include <pty.h>
 #endif
 
+#ifdef HAVE_LOCALE_H
+# include <locale.h>
+#endif
+
 #ifdef HAVE_VALUES_H
 
 /*
