@@ -20,7 +20,7 @@
  *
  *
  * nessus-fetch is a simple utility to retrieve Nessus plugins from nessus.org
- * $Id: nessus-fetch.c,v 1.6 2004/12/11 01:13:17 renaud Exp $
+ * $Id: nessus-fetch.c,v 1.9 2005/03/17 01:14:56 renaud Exp $
  */
 #include <includes.h>
 
@@ -39,6 +39,9 @@
 #ifndef INADDR_NONE
 #define INADDR_NONE 0xffffffff
 #endif
+
+
+
 static int unblock_socket(int soc)
 {
   int   flags =  fcntl(soc, F_GETFL, 0);
@@ -235,6 +238,8 @@ struct preferences {
 	char * proxy_username;
 	char * proxy_password;
 };
+
+int proxy_connect_method(char * hostname, int port, struct preferences * prefs, struct arglist * hostinfo);
 	
 
 static void save_preferences( struct preferences * prefs )
@@ -573,8 +578,11 @@ static int do_register( char * serial )
   snprintf(str, sizeof(str), "/register.php?serial=%s", serial);
 
  req = mk_http_req(plug_get_hostname(hostinfo), str, NULL, NULL);
+ if ( prefs.proxy && prefs.proxy_port )
+  soc = proxy_connect_method(PLUGINS_NESSUS_ORG, HTTPS_PORT, &prefs, hostinfo);
+ else
+  soc = open_stream_connection(hostinfo, HTTPS_PORT, NESSUS_ENCAPS_TLSv1,  60);
 
- soc = open_stream_connection(hostinfo, ( prefs.proxy && prefs.proxy_port ) ? atoi(prefs.proxy_port) : HTTPS_PORT, NESSUS_ENCAPS_TLSv1,  60);
  if ( soc < 0 ) 
  {
   fprintf(stderr, "could not connect to %s - %s\n", plug_get_hostname(hostinfo), strerror(errno));
@@ -822,6 +830,8 @@ void check_subscription()
   {
   direct_feed = 1;
   snprintf(path, sizeof(path), "/get.php?u=%s&p=%s&f=check", prefs.login, prefs.password);
+
+
   fetch_file(NESSUS_ENCAPS_TLSv1, HTTPS_PORT, PLUGINS_NESSUS_ORG, path, NULL, NULL, NULL, &result);
   if ( result == NULL )
 	{
