@@ -16,10 +16,13 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */   
  
-#ifndef _NESSUSC_ATTACK_H
-#define _NESSUSC_ATTACK_H
 
-void attack_host(char *, struct arglist *);
+
+int attack_host(char *, struct context *);
 void attack_handler();
 
+#ifdef ENABLE_SAVE_TESTS
+void restore_attack(char *, struct context *);
 #endif
+
+
