@@ -37,6 +37,8 @@
 #include "globals.h"
 
 #include "nessus.h"
+#include "context.h"
+#include "preferences.h"
 #include "parser.h"
 #include "cli.h"
 
@@ -120,14 +122,14 @@ static harglst* build_plugins_order_table(order)
   
   for(i=0;i<num;i++)
   {
-   struct arglist * plugs = Plugins;
+   struct arglist * plugs = Context->plugins;
    
    while(plugs && plugs->next && 
         ((int)(arg_get_value(plugs->value, "ID"))!=plugins_order_table_int[i]))
          plugs = plugs->next;
    if(!(plugs && plugs->next))
    {
-    plugs = Scanners;
+    plugs = Context->scanners;
     while(plugs && plugs->next && 
         ((int)(arg_get_value(plugs->value, "ID"))!=plugins_order_table_int[i]))
          plugs = plugs->next;
@@ -174,7 +176,7 @@ cli_test_monitor(cli)
         */
     if(network_gets(buf, sizeof(buf) - 1) < 0 || buf[0] == '\0')
     { 
-       if(!is_server_present(GlobalSocket))
+       if(!is_server_present(Context->socket))
        {
        fprintf(stderr, "nessus: nessusd abruptly shut the communication down - the test may be incomplete\n");
        finished = 1;
@@ -415,21 +417,19 @@ int cli_connect_to_nessusd(cli)
  struct cli_args * cli;
 {
  /*ENABLE_CRYPTO_LAYER*/
- char * pwd = cli->password;
  char * err;
- err = connect_to_nessusd(cli->server,
- 				 cli->port,
-				 cli->login,
-				 pwd);
- 
+ prefs_set_string(Context, "nessusd_host", cli->server);
+ prefs_set_int(Context, "nessusd_port", cli->port);
+ prefs_set_string(Context, "nessusd_user", cli->login);
+ Context->passwd = cli->password;
+ err = connect_to_nessusd(Context);
+
  if(err)
   {
   fprintf(stderr, "nessus : %s\n", err);
   return -1;
  }
  
- bzero(cli->login, strlen(cli->login));
- bzero(cli->password, strlen(cli->password));
  return 0;
 }
 
@@ -445,9 +445,13 @@ int cli_test_network(cli)
       return -1;
   }
 
-  attack_host(target_list, Prefs);
-  cli_test_monitor(cli);
-  return 0 ;
+  if(attack_host(target_list, Context))
+  {
+    cli_test_monitor(cli);
+    return 0;
+  }
+  else
+    return -1;
 }
 
 void
@@ -652,8 +656,8 @@ cli_sql_dump_plugins(cli)
  printf(" bugtraq_id varchar(255),\n");
  printf(" xref blob,\n");
  printf(" primary key (id));\n");
- _cli_sql_dump_plugins(Plugins);
- _cli_sql_dump_plugins(Scanners);
+ _cli_sql_dump_plugins(Context->plugins);
+ _cli_sql_dump_plugins(Context->scanners);
 }
 
 
@@ -661,15 +665,15 @@ void
 cli_dump_plugins(cli)
  struct cli_args * cli;
 {
- _cli_dump_plugins(Plugins);
- _cli_dump_plugins(Scanners);
+ _cli_dump_plugins(Context->plugins);
+ _cli_dump_plugins(Context->scanners);
 }
 
 
 static void
 _cli_dump_pprefs()
 {
- struct arglist * p = arg_get_value(Prefs, "PLUGINS_PREFS");
+ struct arglist * p = arg_get_value(Context->prefs, "PLUGINS_PREFS");
  if(!p)
   return;
   
@@ -702,7 +706,7 @@ void
 cli_dump_prefs(cli)
  struct cli_args * cli;
 {
- struct arglist * p = arg_get_value(Prefs, "SERVER_PREFS");
+ struct arglist * p = arg_get_value(Context->prefs, "SERVER_PREFS");
  if(!p)
   return;
   
@@ -721,8 +725,8 @@ cli_dump_prefs(cli)
  }
  
 
- if(Plugins)_cli_dump_pprefs(Plugins);
- if(Scanners)_cli_dump_pprefs(Scanners);
+ if(Context->plugins)_cli_dump_pprefs(Context->plugins);
+ if(Context->scanners)_cli_dump_pprefs(Context->scanners);
  
  return;
 }
@@ -730,7 +734,7 @@ int
 cli_close_connection(cli)
  struct cli_args * cli;
 {
- return close_stream_connection(GlobalSocket);
+ return close_stream_connection(Context->socket);
 }
 
 #ifdef ENABLE_SAVE_TESTS
@@ -739,7 +743,7 @@ cli_restore_session(cli, session)
  struct cli_args * cli;
  char * session;
 {   
-  restore_attack(session, Prefs);
+  restore_attack(session, Context);
   cli_test_monitor(cli);
 }
 void
@@ -747,19 +751,19 @@ cli_list_sessions(cli)
  struct cli_args * cli;
 {
  hargwalk * hw;
- if(!comm_server_restores_sessions(Prefs))
+ if(!comm_server_restores_sessions(Context))
   printf("** The remote nessusd server does not support session-saving\n");
  else
   {
    char * key;
-   hw = harg_walk_init(Sessions);
+   hw = harg_walk_init(Context->sessions);
    printf("Remote sessions :\n");
    printf("-----------------\n\n");
    printf("Session ID      | Targets\n");
    printf("==========================\n");
    while((key = (char*)harg_walk_next(hw)))
    {
-    printf("%s | %s\n", key, harg_get_string(Sessions, key));
+    printf("%s | %s\n", key, harg_get_string(Context->sessions, key));
    }
   } 
 }
