@@ -1,5 +1,6 @@
 /* Nessus
  * Copyright (C) 1998 - 2001 Renaud Deraison
+ * Copyright (C) 2004, 2005 Intevation GmbH
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -49,6 +50,79 @@
 #define MIN(x,y) ((x) < (y) ? (x) : (y))
 #endif
 
+
+/* Currently active time-consuming task */
+#define COMM_GET_PLUGINS 1
+#define COMM_GET_DEPENDENCIES 2
+
+/*
+ * Update the UI while receiving plugin or dependency information.
+ * For GTK this is displayed with a progress bar (maybe this should
+ * be moved to a separate prefs_progressbar module)
+ */
+static void
+comm_update_ui(context, current)
+  struct context *context;
+  int current;
+{
+#ifdef USE_GTK
+  static int previous = 0;
+  static int number;
+  static int base;
+  static int limit;
+  static const char *fmt;
+  gchar *pbar_text;
+  /* maximum number of steps for the progress bar (plugins + dependencies) */
+# define PBAR_MAX 10000
+
+  if(F_quiet_mode)
+    return; /* there is no UI to update in quiet mode */
+
+  /* the task changes */
+  if(previous != current)
+  {
+    previous = current;
+    number = 0;
+    switch(current)
+    {
+      case COMM_GET_PLUGINS:
+	fmt = _("Receiving plugins: %d");
+	base = 0;
+	limit = PBAR_MAX/2;
+	break;
+      case COMM_GET_DEPENDENCIES:
+	fmt = _("Receiving dependencies: %d");
+	base = limit;
+	limit = PBAR_MAX;
+	break;
+      default:
+    }
+  }
+
+  /* Update progress bar every 10 plugins (every 100 on slow links) */
+  if(++number % (F_show_pixmaps?10:100) == 0)
+  {
+    /* if the progress bar is too short, step back 5% */
+    if(base+number >= limit)
+      base -= PBAR_MAX/20;
+
+    /* update the progress bar */
+    gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(context->pbar),
+	1.0*(base+number)/PBAR_MAX);
+
+    /* update text displayed in the progress bar */
+    pbar_text = g_strdup_printf(fmt, number);
+    gtk_progress_bar_set_text(GTK_PROGRESS_BAR(context->pbar), pbar_text);
+    g_free(pbar_text);
+
+    /* perform pending GUI events */
+    while(gtk_events_pending())
+      gtk_main_iteration();
+  }
+
+#endif /* USE_GTK */
+}
+
 int comm_send_file(char *);
 
 /*
@@ -895,10 +969,7 @@ comm_get_plugins(context)
     return (-1);
   for(;;)
   {
-#ifdef USE_GTK
-    while(gtk_events_pending())
-      gtk_main_iteration();
-#endif
+    comm_update_ui(context, COMM_GET_PLUGINS);
     network_gets(buf, bufsz);
     if(buf[0] == '\0')
     {
@@ -1071,11 +1142,7 @@ comm_get_dependencies(context)
       char *t = strstr(buff, " <|> ");
       char *s;
 
-#ifdef USE_GTK
-      while(gtk_events_pending())
-	gtk_main_iteration();
-#endif
-
+      comm_update_ui(context, COMM_GET_DEPENDENCIES);
       if(t)
       {
 	s = t + 5;
