@@ -27,6 +27,8 @@
  */
  
 #include <includes.h>
+#include "nessus_i18n.h"
+#include "globals.h"
 #ifdef USE_GTK
 #ifdef HAVE_REGEX_SUPPORT
 #include <regex.h>
@@ -52,56 +54,29 @@ static int filter_on_bid = 0;
 static int filter_on_xref = 0;
 
 
-static void
-ask_filter_callback(u1, ctrls)
- GtkWidget * u1;
- struct arglist * ctrls;
-{
- GtkWidget * w = arg_get_value(ctrls, "WINDOW");
- gtk_widget_hide(w);
- if(arg_get_value(ctrls,"CANCEL") == u1)
-  {
-   arg_add_value(ctrls, "FILTER", ARG_STRING, 0, (void*)(-1));
-   return;
-  }
- else {
- 	char * filter = (char*)gtk_entry_get_text(GTK_ENTRY(arg_get_value(ctrls,"ENTRY")));
-	filter_on_name = GTK_TOGGLE_BUTTON(arg_get_value(ctrls, "FILTER_NAME"))->active;
-	filter_on_description = GTK_TOGGLE_BUTTON(arg_get_value(ctrls, "FILTER_DESCRIPTION"))->active;
-	filter_on_summary = GTK_TOGGLE_BUTTON(arg_get_value(ctrls, "FILTER_SUMMARY"))->active;
-	filter_on_author = GTK_TOGGLE_BUTTON(arg_get_value(ctrls, "FILTER_AUTHOR"))->active;
-	filter_on_id = GTK_TOGGLE_BUTTON(arg_get_value(ctrls, "FILTER_ID"))->active;
-	filter_on_category = GTK_TOGGLE_BUTTON(arg_get_value(ctrls, "FILTER_CATEGORY"))->active;
-	filter_on_bid = GTK_TOGGLE_BUTTON(arg_get_value(ctrls, "FILTER_BID"))->active;
-	filter_on_cve =  GTK_TOGGLE_BUTTON(arg_get_value(ctrls, "FILTER_CVE"))->active;
-	filter_on_xref = GTK_TOGGLE_BUTTON(arg_get_value(ctrls, "FILTER_XREF"))->active;
-	arg_add_value(ctrls, "FILTER", ARG_STRING,filter ? strlen(filter):0, filter);
-      }
-}
-
 static struct arglist *
 build_filter_dlog()
 {
- GtkWidget * w, * label, *sep, * button, *entry;
+  GtkWindow * window = GTK_WINDOW(arg_get_value(MainDialog, "WINDOW"));
+  GtkWidget * dialog;
+  GtkWidget * label, *sep, * button, *entry;
  GtkWidget * box, *hbox, *frame,*vbox;
  struct arglist * ctrls = emalloc(sizeof(struct arglist));
- 
- 
- w = gtk_window_new(GTK_WINDOW_TOPLEVEL);
- gtk_window_set_title(GTK_WINDOW(w), "Filter plugins...");
- 
- gtk_container_border_width(GTK_CONTAINER(w), 6);
- arg_add_value(ctrls, "WINDOW", ARG_PTR, -1, w);
- gtk_window_position(GTK_WINDOW(w), GTK_WIN_POS_CENTER);
- gtk_widget_realize(w);
- 
- box = gtk_vbox_new(FALSE, 6);
- gtk_container_add(GTK_CONTAINER(w), box);
- gtk_widget_show(box);
 
- 
- 
- label = gtk_label_new("Filter plugins...");
+  dialog = gtk_dialog_new_with_buttons(_("Filter plugins..."), window,
+             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+             GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
+  gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_CANCEL);
+  gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
+  gtk_dialog_set_has_separator(GTK_DIALOG(dialog), FALSE);
+
+  arg_add_value(ctrls, "WINDOW", ARG_PTR, -1, dialog);
+
+  /* The overall vbox */
+  box = GTK_DIALOG(dialog)->vbox;
+
+ label = gtk_label_new(_("Filter plugins..."));
  gtk_box_pack_start(GTK_BOX(box), label, FALSE, FALSE, 1);
  gtk_widget_show(label);
  sep = gtk_hseparator_new();
@@ -113,7 +88,7 @@ build_filter_dlog()
  
  hbox = gtk_hbox_new(FALSE, FALSE);
  gtk_box_pack_start(GTK_BOX(box), hbox, FALSE, FALSE, 3);
- label = gtk_label_new("Pattern : ");
+ label = gtk_label_new(_("Pattern:"));
  gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 6);
  gtk_widget_show(label);
  
@@ -123,7 +98,7 @@ build_filter_dlog()
  gtk_widget_show(entry);
  gtk_widget_show(hbox);
  
- frame = gtk_frame_new("Filter on : ");
+ frame = gtk_frame_new(_("Filter on:"));
  gtk_box_pack_start(GTK_BOX(box), frame, FALSE, FALSE, 6);
  vbox = gtk_vbox_new(FALSE, FALSE);
  gtk_container_border_width(GTK_CONTAINER(frame), 6);
@@ -131,56 +106,56 @@ build_filter_dlog()
  gtk_widget_show(vbox);
  
  /*--------------------------------------------*/
- button = gtk_check_button_new_with_label("Name");
+ button = gtk_check_button_new_with_label(_("Name"));
  gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 3);
  gtk_widget_show(button);
  arg_add_value(ctrls, "FILTER_NAME", ARG_PTR, -1, button);
  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(button), filter_on_name);
  /*--------------------------------------------*/
- button = gtk_check_button_new_with_label("Description");
+ button = gtk_check_button_new_with_label(_("Description"));
  gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 3);
  gtk_widget_show(button);
  arg_add_value(ctrls, "FILTER_DESCRIPTION", ARG_PTR, -1, button);
  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(button), filter_on_description);
  /*--------------------------------------------*/
- button = gtk_check_button_new_with_label("Summary");
+ button = gtk_check_button_new_with_label(_("Summary"));
  gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 3);
  gtk_widget_show(button);
  arg_add_value(ctrls, "FILTER_SUMMARY", ARG_PTR, -1, button);
  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(button), filter_on_summary);
  /*--------------------------------------------*/
- button = gtk_check_button_new_with_label("Author");
+ button = gtk_check_button_new_with_label(_("Author"));
  gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 3);
  gtk_widget_show(button);
  arg_add_value(ctrls, "FILTER_AUTHOR", ARG_PTR, -1, button);
  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(button), filter_on_author);
  /*--------------------------------------------*/
- button = gtk_check_button_new_with_label("ID number");
+ button = gtk_check_button_new_with_label(_("ID number"));
  gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 3);
  gtk_widget_show(button);
  arg_add_value(ctrls, "FILTER_ID", ARG_PTR, -1, button);
  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(button), filter_on_id);
  /*--------------------------------------------*/
- button = gtk_check_button_new_with_label("Category");
+ button = gtk_check_button_new_with_label(_("Category"));
  gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 3);
  gtk_widget_show(button);
  arg_add_value(ctrls, "FILTER_CATEGORY", ARG_PTR, -1, button);
  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(button), filter_on_category);
  /*--------------------------------------------*/
- button = gtk_check_button_new_with_label("CVE");
+ button = gtk_check_button_new_with_label(_("CVE"));
  gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 3);
  gtk_widget_show(button);
  arg_add_value(ctrls, "FILTER_CVE", ARG_PTR, -1, button);
  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(button), filter_on_cve);
   /*--------------------------------------------*/
- button = gtk_check_button_new_with_label("BID");
+ button = gtk_check_button_new_with_label(_("BID"));
  gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 3);
  gtk_widget_show(button);
  arg_add_value(ctrls, "FILTER_BID", ARG_PTR, -1, button);
  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(button), filter_on_bid);
  
   /*--------------------------------------------*/
- button = gtk_check_button_new_with_label("XREF");
+ button = gtk_check_button_new_with_label(_("XREF"));
  gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 3);
  gtk_widget_show(button);
  arg_add_value(ctrls, "FILTER_XREF", ARG_PTR, -1, button);
@@ -188,32 +163,8 @@ build_filter_dlog()
  
  
  gtk_widget_show(frame);
- 
- hbox = gtk_hbox_new(TRUE, 6);
- gtk_box_pack_start(GTK_BOX(box), hbox,FALSE, FALSE, 6);
- gtk_widget_show(hbox);
- 
- button = gtk_button_new_with_label("OK");
- gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 6);
- GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
- gtk_widget_grab_default(button);
- gtk_widget_show(button);
- 
- gtk_signal_connect(GTK_OBJECT(button), "clicked", 
- 		    (GtkSignalFunc)ask_filter_callback, 
-		    (void*)ctrls);
-		    
-		    
- button = gtk_button_new_with_label("Cancel");
- arg_add_value(ctrls, "CANCEL", ARG_PTR, -1, button);
- gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 6);
- gtk_signal_connect(GTK_OBJECT(button), "clicked", 
- 		    (GtkSignalFunc)ask_filter_callback, 
-		    (void*)ctrls);
- gtk_widget_show(button);;
- 
- gtk_widget_show(w);
- gtk_grab_add(w);
+
+ gtk_widget_show(dialog);
  return ctrls;
 } 
  
@@ -222,19 +173,45 @@ int ask_filter(filter)
  struct plugin_filter * filter;
 {
  struct arglist * ctrls = build_filter_dlog();
- char * ret;
-  while(!arg_get_value(ctrls, "FILTER"))
-  while(gtk_events_pending()){
-  	gtk_main_iteration();
-#if !defined(WIN32) && !defined(_WIN32)
-	usleep(10000);
-#endif
-	}	
+ GtkWidget * dialog;
+ char * pattern = NULL;
 
- ret = arg_get_value(ctrls, "FILTER");
- if(ret == (void*)-1)filter->pattern = NULL;
- else filter->pattern = estrdup(ret);
- 
+  dialog = arg_get_value(ctrls,"WINDOW");
+
+  switch (gtk_dialog_run(GTK_DIALOG(dialog)))
+  {
+    case GTK_RESPONSE_OK:
+      pattern = (char*)gtk_entry_get_text(GTK_ENTRY(
+        arg_get_value(ctrls,"ENTRY")));
+      filter_on_name = GTK_TOGGLE_BUTTON(
+        arg_get_value(ctrls, "FILTER_NAME"))->active;
+      filter_on_description = GTK_TOGGLE_BUTTON(
+        arg_get_value(ctrls, "FILTER_DESCRIPTION"))->active;
+      filter_on_summary = GTK_TOGGLE_BUTTON(
+        arg_get_value(ctrls, "FILTER_SUMMARY"))->active;
+      filter_on_author = GTK_TOGGLE_BUTTON(
+        arg_get_value(ctrls, "FILTER_AUTHOR"))->active;
+      filter_on_id = GTK_TOGGLE_BUTTON(
+        arg_get_value(ctrls, "FILTER_ID"))->active;
+      filter_on_category = GTK_TOGGLE_BUTTON(
+        arg_get_value(ctrls, "FILTER_CATEGORY"))->active;
+      filter_on_bid = GTK_TOGGLE_BUTTON(
+        arg_get_value(ctrls, "FILTER_BID"))->active;
+      filter_on_cve =  GTK_TOGGLE_BUTTON(
+        arg_get_value(ctrls, "FILTER_CVE"))->active;
+      filter_on_xref = GTK_TOGGLE_BUTTON(
+        arg_get_value(ctrls, "FILTER_XREF"))->active;
+      break;
+    default: /* pattern remains NULL */
+      break;
+  }
+
+  if (!pattern)
+    filter->pattern = NULL;
+  else
+    filter->pattern = estrdup(pattern);
+
+  printf("P: %s\n", pattern);
  filter->filter_on_name = filter_on_name;
  filter->filter_on_description = filter_on_description;
  filter->filter_on_summary = filter_on_summary;
@@ -244,8 +221,8 @@ int ask_filter(filter)
  filter->filter_on_cve = filter_on_cve;
  filter->filter_on_bid = filter_on_bid;
  filter->filter_on_xref = filter_on_xref;
- 
- gtk_widget_destroy(arg_get_value(ctrls, "WINDOW"));
+
+ gtk_widget_destroy(dialog);
  arg_free(ctrls);
  return 0;
 }
@@ -258,7 +235,7 @@ char *
 ask_filter()
 {
  char * ret = emalloc(1024);
- printf("Enter a new filter : ");
+ printf(_("Enter a new filter : "));
  fgets(ret, 1023, stdin);
  return ret;
 }
@@ -279,7 +256,7 @@ static int match(str, pat)
   re_set_syntax(RE_SYNTAX_POSIX_EGREP);
   if(regcomp(&re, pat, REG_EXTENDED|REG_ICASE))
   {
-   show_error("Invalid regular expression");
+   show_error(_("Invalid regular expression"));
    bzero(pat, strlen(pat));
    return -1;
   }
