@@ -73,6 +73,7 @@
 #include "report_utils.h"
 #include "error_dialog.h"
 #include "nsr_output.h"
+#include "preferences.h"
 
 
 static void insert_img(FILE *, char*);
@@ -487,11 +488,71 @@ most_used_operating_systems(hosts, names, values, n)
 			Single host report
 			
 -----------------------------------------------------------------------------*/
+
+/*
+ * print URL linking to CVE/BID/Nessus database to file.
+ * '%s' in urlfmt (from preferences) will be replaced by
+ * item IDs (or their parts split at minus characters).
+ * '%%' will insert a percent character.
+ * Everything else after '%' aborts parsing.
+ * If urlfmt yields an empty string (e.g. it is only "%"),
+ * only the item ID will be printed.
+ */
+static void
+fprint_link(file, key, item)
+  FILE *file;
+  const char *key;
+  const char *item;
+{
+  char *itemparts = estrdup(item);
+  char *itemsrc = itemparts;
+  char *urlfmt = estrdup(prefs_get_string(Global, key));
+  char *src = urlfmt;
+  char *url = emalloc(strlen(urlfmt)+strlen(item)+1);
+  char *dst = url;
+  char *tmp;
+
+  while((tmp = strchr(src, '%')))
+  {
+    *tmp = '\0';
+    strcpy(dst, src);
+    dst += strlen(src);
+    src = tmp+1;
+    switch(*src)
+    {
+      case 's':
+	if((tmp = strchr(itemsrc, '-')))
+	  *tmp = '\0';
+	strcpy(dst, itemsrc);
+	dst += strlen(itemsrc);
+	if(tmp)
+	  itemsrc = tmp+1;
+	src++;
+	break;
+      case '%':
+	strcpy(dst++, "%");
+	src++;
+	break;
+      default:
+	*src = '\0';
+    }
+  }
+  strcpy(dst, src);
+
+  efree(&itemparts);
+  efree(&urlfmt);
+  if(*url)
+    fprintf(file, "<a href=\"%s\">%s</a>", url, item);
+  else
+    fprintf(file, "%s", item);
+  efree(&url);
+}
+
 /* All the cross references (CVE, BID) have the same format - XREF: <num>,...<br> */
 static char * 
-extract_xref(file, str, url)
+extract_xref(file, str, key)
  FILE * file;
- char * str, * url;
+ char * str, * key;
 {
  while(str != NULL && strncmp(str, "<br>", 4) != 0)
    {
@@ -506,7 +567,7 @@ extract_xref(file, str, url)
      tmp = e1[0];
      e1[0] = '\0';
     }
-    fprintf(file, "<a href=\"%s%s\">%s</a>", url, str, str);
+    fprint_link(file, key, str);
     str = e1;
     if(e1 != NULL)
     {
@@ -557,20 +618,21 @@ print_data_with_links(file, str, plugin_id)
   {
    fprintf(file, "CVE : ");
    str += 6;
-   str = extract_xref(file, str, "http://cgi.nessus.org/cve.php3?cve=");
+   str = extract_xref(file, str, "url_cve");
   }
   else if(strncmp(str, "BID : ", 6) == 0)
   {
   fprintf(file, "BID : ");
   str += 6;
-  str = extract_xref(file, str, "http://cgi.nessus.org/bid.php3?bid=");
+  str = extract_xref(file, str, "url_bid");
   }
   else fputc(str[0], file);
   if(str != NULL)
     str++;
  }
  
- fprintf(file, "Nessus ID : <a href=\"http://cgi.nessus.org/nessus_id.php3?id=%s\">%s</a>", plugin_id, plugin_id);
+ fprintf(file, "Nessus ID : ");
+ fprint_link(file, "url_nessus", plugin_id);
 }
 
 static char * convert_cr_to_html(str)
