@@ -29,7 +29,7 @@
 #include <includes.h>
 #include "report.h"
 #include "report_utils.h"
-#include "globals.h"
+#include "context.h"
 #include "text_output.h"
 #define CATEGORY_A 0
 #define CATEGORY_B 1
@@ -146,7 +146,7 @@ void latex_introduction_a(FILE * f, struct arglist * hosts, int holes, int warni
  if(num_of_hosts > 1)fprintf(f, "s");
  fprintf(f," and none of the vulnerabilities tested were present on this ");
  fprintf(f,"network ");
- if(Scanners && Plugins)
+ if(Context->scanners && Context->plugins)
  {
  fprintf(f, "(see Appendix A and B page \\pageref{appendix_a} and page \\pageref{appendix_b} for the exhaustive ");
  fprintf(f,"list of what was tested).\\\\\n");
@@ -181,7 +181,7 @@ void latex_introduction_b(FILE * f, struct arglist * hosts, int holes, int warni
   		most->name);
   fprintf(f, "the most affected by these warnings.\\\\\n");
  }
- if(Scanners && Plugins)
+ if(Context->scanners && Context->plugins)
  {
  fprintf(f, "(see Appendix A and B page \\pageref{appendix_a} and page \\pageref{appendix_b} for the exhaustive ");
  fprintf(f,"list of what was tested).\\\\\n");
@@ -219,7 +219,7 @@ int latex_introduction_c(FILE * f, struct arglist * hosts, int holes, int warnin
   fprintf(f, "the most affected by these warnings.\\\\\n");
  }
 
- if(Scanners && Plugins)
+ if(Context->scanners && Context->plugins)
  {
  fprintf(f, "(see Appendix A and B page \\pageref{appendix_a} and page \\pageref{appendix_b} for the exhaustive ");
  fprintf(f,"list of what was tested).\\\\\n");
@@ -253,7 +253,7 @@ int latex_introduction_d(FILE * f, struct arglist * hosts, int holes, int warnin
   fprintf(f, "that is the most likely to be the entry point of any cracker.\n");
  }
  
- if(Scanners && Plugins)
+ if(Context->scanners && Context->plugins)
  {
  fprintf(f, "You should have a look at ");
  fprintf(f, "(see Appendix A and B page \\pageref{appendix_a} and page \\pageref{appendix_b} for the exhaustive ");
@@ -287,7 +287,7 @@ int latex_introduction_e(FILE * f, struct arglist * hosts, int holes, int warnin
   		most->name);
   fprintf(f, "that is the most likely to be the entry point of any cracker.\n");
  }
-if(Scanners && Plugins)
+if(Context->scanners && Context->plugins)
  {
  fprintf(f, "You should have a look at ");
  fprintf(f, "(see Appendix A and B page \\pageref{appendix_a} and page \\pageref{appendix_b} for the exhaustive ");
@@ -485,19 +485,19 @@ void latex_appendix_plugins(FILE * f, struct arglist * plugins)
 }
 void latex_appendix(FILE *f)
 {
-  if(Scanners || Plugins)
+  if(Context->scanners || Context->plugins)
   {
   fprintf(f, "\\newpage\n");
   fprintf(f, "\\label{appendix_a}\n");
   fprintf(f, "\\appendix\n");
   fprintf(f, "\\section{List of port scanners used during this session}\n");
   fprintf(f, "\\begin{itemize}\n");
-  latex_appendix_plugins(f, Scanners);
+  latex_appendix_plugins(f, Context->scanners);
   fprintf(f, "\\end{itemize}\n");
   fprintf(f, "\\label{appendix_b}\n");
   fprintf(f, "\\section{List of plugins used during this session}\n");
   fprintf(f, "\\begin{itemize}\n");
-  latex_appendix_plugins(f, Plugins);
+  latex_appendix_plugins(f, Context->plugins);
   fprintf(f, "\\end{itemize}\n");
  }
 }
