@@ -19,5 +19,5 @@
 #ifndef _NESSUSC_MONITOR_DIALOG_H
 #define _NESSUSC_MONITOR_DIALOG_H
 
-void monitor_dialog_setup(char *, int);
+void monitor_dialog_setup(char *);
 #endif
