@@ -1,5 +1,5 @@
 /* Nessus
- * Copyright (C) 1998 - 2006 Tenable Network Security, Inc. 
+ * Copyright (C) 1998 - 2001 Renaud Deraison
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2,
@@ -28,19 +28,18 @@
  */
 
 #include <includes.h>
+
+#include "nessus_i18n.h"
 #include "password_dialog.h"
 
 #ifdef USE_GTK
 #include <gtk/gtk.h>
 #include "xstuff.h"
-#include "error_dialog.h"
 #include "prefs_dialog/prefs_dialog.h"
-#include "prefs_dialog/prefs_dialog_plugins_prefs.h"
-#include "prefs_dialog/prefs_dialog_scan_opt.h"
-#include "prefs_dialog/prefs_target.h"
-#include "report_ng.h"
+#include "prefs_dialog/prefs_context.h"
 #endif
 
+#include "error_dialog.h"
 #include "read_target_file.h"
 #include "comm.h"
 #include "auth.h"
@@ -49,11 +48,11 @@
 #include "report.h"
 #include "parser.h"
 #include "sighand.h"
+#include "context.h"
 #include "preferences.h"
 #include "globals.h"
 #include "corevers.h"
 #include <getopt.h>
-#include "password_dialog.h"
 #include "filter.h"
 
 #include "backend.h"
@@ -66,18 +65,12 @@
 #include "xml_output.h"
 #include "xml_output_ng.h"
 
-
-
 #include "cli.h"
 
 #ifdef HAVE_SSL
 #include <openssl/x509v3.h>
 #endif
 
-#ifdef ENABLE_SAVE_TESTS
-#include "detached_index.h"
-#endif
-
 #ifdef USE_AF_UNIX
 #undef NESSUS_ON_SSL
 #endif
@@ -94,33 +87,12 @@
 #define inc_optind() (optind++)
 #endif
 
-struct arglist * Plugins  = NULL;
-struct arglist * Scanners = NULL;
-struct arglist * Dependencies = NULL;
-struct arglist * Upload   = NULL;
-#ifdef ENABLE_SAVE_TESTS
-harglst * Sessions = NULL;
-int Sessions_saved = 0;
-int Detached_sessions_saved = 0;
-#endif
-#ifdef ENABLE_SAVE_KB
-int DetachedMode = 0;
-#endif
-
-int PluginsNum;
-int ScannersNum;
-struct arglist * Prefs;
 struct arglist * MainDialog;
-struct arglist * ArgSock;
 char * Alt_rcfile = NULL;
 struct plugin_filter Filter;
-int GlobalSocket;
-char * stored_pwd = NULL;
 int DontCheckServerCert = 0;
 int F_show_pixmaps;
 int F_quiet_mode;
-int F_nessusd_running;
-int First_time = 0;
 int ListOnly = 0;
 
 #ifndef USE_AF_INET      
@@ -130,6 +102,19 @@ int ListOnly = 0;
 
 void init_globals();
 
+/*
+ * Initialize I18N support, if possible
+ */
+static void
+i18n_init(void)
+{
+#ifdef HAVE_GNU_GETTEXT
+  setlocale (LC_ALL, "" );
+  bindtextdomain (PACKAGE, LOCALEDIR);
+  bind_textdomain_codeset (PACKAGE, "UTF-8");
+  textdomain (PACKAGE);
+#endif
+}
 
 
 #ifdef NESSUS_ON_SSL
@@ -190,7 +175,7 @@ get_server_cert_hash(sname, hash)
   int	i, x;
 
 
-  if ((fname = preferences_get_altname("cert")) == NULL)
+  if ((fname = preferences_get_altname(Global, "cert")) == NULL)
     return -1;
 
   fp = fopen(fname, "r");
@@ -249,7 +234,7 @@ set_server_cert_hash(sname, hash)
   int	x;
   int	found;
 
-  if ((fname = preferences_get_altname("cert")) == NULL)
+  if ((fname = preferences_get_altname(Global, "cert")) == NULL)
     return -1;
   
   if ((fp2 = tmpfile()) == NULL)
@@ -331,12 +316,12 @@ set_server_cert_hash(sname, hash)
  *
  */
 char *
-connect_to_nessusd(hostname, port, login, pass)
-	char * hostname;
-	int port;
-	char * login;
-	char * pass; /* is a cipher in case of the crypto layer */
+connect_to_nessusd(context)
+	struct context * context;
 {
+  const char * hostname;
+  int port;
+  const char * login;
 #ifdef CLN_AUTH_SRV
   int	paranoia_level;
   /*
@@ -350,9 +335,11 @@ connect_to_nessusd(hostname, port, login, pass)
   static SSL_CTX	*ssl_ctx = NULL;
   static SSL_METHOD	*ssl_mt = NULL;
   SSL		*ssl = NULL;
-  char		*cert, *key, *client_ca, *trusted_ca, *ssl_ver;
-  char		*ssl_cipher_list;
+  const char	*cert, *key, *client_ca, *trusted_ca, *ssl_ver;
+  const char	*ssl_cipher_list;
   STACK_OF(X509_NAME)	*cert_names;
+  int use_client_cert = prefs_get_int(context, "use_client_cert");
+  char *pem_pass = NULL;
 #endif
   int soc, soc2;
   int opt;
@@ -360,32 +347,21 @@ connect_to_nessusd(hostname, port, login, pass)
   struct sockaddr_un address;
   char * name = AF_UNIX_PATH;
 #endif
+  const char *passwd;
 
-  init_globals();
-  if(arg_get_type(Prefs, "nessusd_host")>=0)
-   arg_set_value(Prefs, "nessusd_host", strlen(hostname), strdup(hostname));
+  if(prefs_get_int(Global, "nessusd_autoconnect"))
+    passwd = estrdup(context->passwd);
   else
-   arg_add_value(Prefs, "nessusd_host", ARG_STRING, strlen(hostname),
-   		strdup(hostname));
-			
-  if(arg_get_type(Prefs, "nessusd_user")>=0)
-   arg_set_value(Prefs, "nessusd_user", strlen(login), strdup(login));
-  else
-   arg_add_value(Prefs, "nessusd_user", ARG_STRING, strlen(login),
-   		strdup(login));		
+  {
+    /* Don't cache the password */
+    passwd = context->passwd;
+    context->passwd = NULL;
+  }
+
+  hostname = prefs_get_string(context, "nessusd_host");
+  port = prefs_get_int(context, "nessusd_port");
+  login = prefs_get_string(context, "nessusd_user");
 
-#ifdef CLN_AUTH_SRV
-  paranoia_level = (int) arg_get_value(Prefs, "paranoia_level");
-  if(!paranoia_level && !DontCheckServerCert){
-  	paranoia_level = sslui_ask_paranoia_level();
-	if(paranoia_level >= 1 && paranoia_level <= 3)
-	{
-	arg_add_value(Prefs, "paranoia_level", ARG_INT, sizeof(int),(void*)paranoia_level);
-	preferences_save(Plugins);
-	}
-	}	
-#endif
-   
 #ifdef USE_AF_INET
   soc = open_sock_tcp_hn(hostname, port);
   
@@ -395,10 +371,10 @@ connect_to_nessusd(hostname, port, login, pass)
   	static char err_msg[1024];
   	struct in_addr a = nn_resolve(hostname);
 	if(a.s_addr == INADDR_NONE) 
-		return("Host not found !");
+		return _("Host not found!");
   	else
 		{
-		snprintf(err_msg, sizeof(err_msg), "Could not open a connection to %s\n", hostname);
+		snprintf(err_msg, sizeof(err_msg), _("Could not open a connection to %s\n"), hostname);
   		return err_msg;
 		}
   	}
@@ -417,24 +393,37 @@ connect_to_nessusd(hostname, port, login, pass)
   if(connect(soc, (struct sockaddr*)&address, sizeof(address))==-1)
   {
 	char * error = emalloc(255+strlen(name)+strlen(strerror(errno)));
-	sprintf(error, "Could not connect to %s - %s\n", name, strerror(errno));
+	sprintf(error, _("Could not connect to %s - %s\n"), name, strerror(errno));
 	return error;
   }
 #endif  
 
 #ifdef NESSUS_ON_SSL
-#define SSL_VER_DEF_NAME	"TLSv1"
-#define SSL_VER_DEF_METH	TLSv1_client_method
-  ssl_ver = arg_get_value(Prefs, "ssl_version");
-  if (ssl_ver == NULL || *ssl_ver == '\0')
-    ssl_ver = SSL_VER_DEF_NAME;
+  if (prefs_get_int(context, "use_ssl"))
+  {
+    ssl_ver = prefs_get_string(context, "ssl_version");
+    if (!strcasecmp(ssl_ver, "NONE"))
+      ssl_ver = prefs_get_default(context, "ssl_version");
+  }
+  else
+    ssl_ver = "NONE";
 
   if (strcasecmp(ssl_ver, "NONE") != 0)
     {
+#ifdef CLN_AUTH_SRV
+      paranoia_level = prefs_get_int(context, "paranoia_level");
+      if(!paranoia_level && !DontCheckServerCert)
+      {
+	paranoia_level = sslui_ask_paranoia_level();
+	if(paranoia_level >= 1 && paranoia_level <= 3)
+	  prefs_set_int(context, "paranoia_level", paranoia_level);
+      }
+#endif
+
       if(nessus_SSL_init(NULL) < 0)
 	{
-	  return("Could not initialize the OpenSSL library !\n\
-Please launch nessus-mkrand(1) first !");
+	  return(_("Could not initialize the OpenSSL library !\n\
+Please launch nessus-mkrand(1) first !"));
 	}
       if (ssl_mt == NULL)
 	{
@@ -448,7 +437,9 @@ Please launch nessus-mkrand(1) first !");
 	    ssl_mt = TLSv1_client_method();
 	  else
 	    {
-	      fprintf(stderr, "Unknown SSL version \"%s\"\nSwitching to default " SSL_VER_DEF_NAME "\n", ssl_ver);
+	      show_warning(
+		  _("Unknown SSL version \"%s\"\nUsing default: %s"),
+		  ssl_ver, SSL_VER_DEF_NAME);
 	      ssl_ver = SSL_VER_DEF_NAME;
 	      ssl_mt = SSL_VER_DEF_METH();
 	    }
@@ -475,7 +466,7 @@ Please launch nessus-mkrand(1) first !");
 #define NOEXP_CIPHER_LIST "EDH-RSA-DES-CBC3-SHA:EDH-DSS-DES-CBC3-SHA:DES-CBC3-SHA:DES-CBC3-MD5:DHE-DSS-RC4-SHA:IDEA-CBC-SHA:RC4-SHA:RC4-MD5:IDEA-CBC-MD5:RC2-CBC-MD5:RC4-MD5:RC4-64-MD5:EDH-RSA-DES-CBC-SHA:EDH-DSS-DES-CBC-SHA:DES-CBC-SHA:DES-CBC-MD5"
 #define STRONG_CIPHER_LIST "EDH-RSA-DES-CBC3-SHA:EDH-DSS-DES-CBC3-SHA:DES-CBC3-SHA:DES-CBC3-MD5:DHE-DSS-RC4-SHA:IDEA-CBC-SHA:RC4-SHA:RC4-MD5:IDEA-CBC-MD5:RC2-CBC-MD5:RC4-MD5"
 #define EDH_CIPHER_LIST "EDH-RSA-DES-CBC3-SHA:EDH-DSS-DES-CBC3-SHA:DHE-DSS-RC4-SHA"
-      ssl_cipher_list = arg_get_value(Prefs, "ssl_cipher_list");
+      ssl_cipher_list = prefs_get_string(context, "ssl_cipher_list");
       if (ssl_cipher_list != NULL && *ssl_cipher_list != '\0' )
 	{
 	  if (strcmp(ssl_cipher_list, "noexp") == 0)
@@ -494,14 +485,19 @@ Please launch nessus-mkrand(1) first !");
 	  sslerror("SSL_new");
 	  return "SSL_error";
 	}
-      cert = arg_get_value(Prefs, "cert_file");
-      key = arg_get_value(Prefs, "key_file");
-      client_ca = arg_get_value(Prefs, "client_ca");
 
-      if (pass != NULL && key != NULL)
+      if(use_client_cert)
+      {
+      cert = prefs_get_string(context, "cert_file");
+      key = prefs_get_string(context, "key_file");
+      client_ca = prefs_get_string(context, "client_ca");
+
+      if(passwd && key)
 	{
-	  nessus_install_passwd_cb(ssl_ctx, pass);
-	 /*  pass = "*"; */	/* So that we do not send it over the network */
+	  pem_pass = estrdup(passwd);
+	  nessus_install_passwd_cb(ssl_ctx, pem_pass);
+	  efree(&passwd);
+	  passwd = estrdup("*"); /* Do not send it over the network */
 	}
 
       if (cert != NULL)
@@ -517,14 +513,16 @@ Please launch nessus-mkrand(1) first !");
 	  else
 	    sslerror("SSL_load_client_CA_file");
 	}
+      }
 #ifdef CLN_AUTH_SRV
       if (paranoia_level == 2 || paranoia_level == 3)
 	{
-	  trusted_ca = arg_get_value(Prefs, "trusted_ca");
+	  trusted_ca = prefs_get_string(context, "trusted_ca");
 	  if (trusted_ca == NULL)
 	    {
-	      fprintf(stderr, "paranoia_level=%d but \"trusted_ca\"not set\n", 
-		      paranoia_level);
+	      show_warning(
+		  _("paranoia_level=%d but \"trusted_ca\" not set"),
+		  paranoia_level);
 	      paranoia_level = 1;
 	    }
 	  else
@@ -535,7 +533,13 @@ Please launch nessus-mkrand(1) first !");
 		sslerror("SSL_CTX_set_default_verify_paths");
 #endif  
 	      if (! SSL_CTX_load_verify_locations(ssl_ctx, trusted_ca, NULL))
-		sslerror("SSL_CTX_load_verify_locations");
+		{
+		  sslerror("SSL_CTX_load_verify_locations");
+		  show_warning(
+		      _("Error while setting the trusted CA: %s\n"
+			"SSL connections are likely to fail."),
+		      trusted_ca);
+		}
 	    }
 	}
 #endif    
@@ -543,6 +547,8 @@ Please launch nessus-mkrand(1) first !");
       if (! SSL_set_fd(ssl, soc))
 	{
 	  sslerror("SSL_set_fd");
+	  efree(&passwd);
+	  efree(&pem_pass);
 	  return "SSL error";
 	}
 
@@ -550,6 +556,8 @@ Please launch nessus-mkrand(1) first !");
       if (SSL_connect(ssl) <= 0)
 	{
 	  sslerror("SSL_connect");
+	  efree(&passwd);
+	  efree(&pem_pass);
 	  return "SSL error";
 	}
 
@@ -573,16 +581,23 @@ Please launch nessus-mkrand(1) first !");
 	  if(cert == NULL)
 	    {
 	      sslerror("SSL_get_peer_certificate");
-	      return "SSL error: cannot get server certificate";
+	      return _("SSL error: cannot get server certificate");
+	      efree(&passwd);
+	      efree(&pem_pass);
 	    }
 	  X509_check_purpose(cert, -1, 0); /* Make sure hash is correct */
 	  if (memcmp(cert->sha1_hash, stored_hash, SHA_DIGEST_LENGTH) != 0)
 	    {
 	      int x = sslui_check_cert(ssl);
-	      if(x < 0)return "Invalid server certificate";
+	      if(x < 0)
+	      {
+		efree(&passwd);
+		efree(&pem_pass);
+		return _("Invalid server certificate");
+	      }
 
 	      if (set_server_cert_hash(hostname, cert->sha1_hash) < 0)
-		perror("Could not save server certificate");
+		perror(_("Could not save server certificate"));
 	    }
 	}
 #endif
@@ -591,7 +606,9 @@ Please launch nessus-mkrand(1) first !");
   if ((soc2 = nessus_register_connection(soc, ssl)) <0)
     {
       shutdown(soc, 2);
-      return "Could not register the connection";
+      efree(&passwd);
+      efree(&pem_pass);
+      return _("Could not register the connection");
     }
   stream_set_buffer(soc2, 1024 * 1024);
   soc = soc2;
@@ -599,96 +616,55 @@ Please launch nessus-mkrand(1) first !");
 #else 
   if((soc2 = nessus_register_connection(soc, NULL)) < 0)
    {
-    return "Could not register the connection";
+    efree(&passwd);
+    return _("Could not register the connection");
    }
   stream_set_buffer(soc2, 1024 * 1024);
    soc = soc2;
 #endif 
-  GlobalSocket = soc;
-  ArgSock = emalloc(sizeof(struct arglist));
-  arg_add_value(ArgSock, "global_socket", ARG_INT, -1, (void *)GlobalSocket);
+  context->socket = soc;
 
-
-  if(comm_init(soc,PROTO_NAME) || (auth_login(login, pass)))
+  if(comm_init(soc,PROTO_NAME) || (auth_login(login, passwd)))
     {
 #ifdef NESSUS_ON_SSL
-      close_stream_connection(GlobalSocket);
+      close_stream_connection(context->socket);
+      efree(&pem_pass);
 #else
-      shutdown(soc, 2);
+      shutdown(context->socket, 2);
 #endif
-      return("Remote host is not using the good version of the Nessus communication protocol (1.2) or is tcpwrapped");
+      context->socket = -1;
+      efree(&passwd);
+      return(_("Remote host is not using the good version of the Nessus communication protocol (1.2) or is tcpwrapped"));
     }
-  if(comm_get_plugins())return("Login failed");
-  if(F_quiet_mode)
-  {
-  	cli_comm_get_preferences(Prefs);
-	comm_get_rules(Prefs);
-	comm_get_dependencies();
-  }
-  else
-  {
-  if(!First_time){
-	comm_get_preferences(Prefs);
-  	comm_get_rules(Prefs);	
-	comm_get_dependencies();
-	}
-  else
-  	{
-	/*
-	 * Ignore the server preferences if we already logged in
-	 */
-	struct arglist * devnull = emalloc(sizeof(*devnull));
-	comm_get_preferences(devnull);
-	comm_get_rules(devnull);
-	arg_free(devnull);
-	}
-  }
 
-	if(comm_server_restores_sessions(Prefs))
-	  {
-	  Sessions = comm_get_sessions();
-#ifdef USE_GTK	  
-	  prefs_dialog_target_fill_sessions(arg_get_value(MainDialog, "TARGET"),
-	  		                    Sessions);
-#endif					    
-	 }
+  if(comm_get_plugins(context))
+  {
+#ifdef NESSUS_ON_SSL
+    close_stream_connection(context->socket);
+    efree(&pem_pass);
+#else
+    shutdown(context->socket, 2);
+#endif
+    context->socket = -1;
+    efree(&passwd);
+    return(_("Login failed"));
+  }
+  comm_get_preferences(context);
+  comm_get_rules(context);
+  comm_get_dependencies(context);
 
- 
-  	
-  prefs_check_defaults(Prefs);
 #ifdef ENABLE_SAVE_TESTS
-#ifdef USE_GTK
-  if(comm_server_detached_sessions(Prefs))
-    detached_show_window(Prefs);
-#endif  
+  if(comm_server_restores_sessions(context))
+    context->sessions = comm_get_sessions();
 #endif
 
-  
-#ifdef USE_GTK
-  prefs_plugins_reset(arg_get_value(MainDialog, "PLUGINS_PREFS"), Plugins,
-   			Scanners);
+  efree(&passwd);
+#ifdef NESSUS_ON_SSL
+  efree(&pem_pass);
 #endif
-#ifdef USE_GTK
-  if(!F_quiet_mode)fill_scanner_list(arg_get_value(MainDialog, "SCAN_OPTIONS"));
-#endif	
-  
   return(NULL);
 }
 
-/*
- * init_globals
- *
- * initializes two main global variables : plugins and
- * scanners
- *
- */
-void 
-init_globals()
-{
-  if(!Plugins)Plugins = emalloc(sizeof(struct arglist));
-  if(!Scanners)Scanners = emalloc(sizeof(struct arglist));
-}
-
 
 void 
 display_help 
@@ -697,39 +673,39 @@ display_help
   
  printf("%s, version %s\n", pname, NESSUS_FULL_VERSION);
 #ifdef USE_AF_INET
- printf("\nCommon options :\n %s [-vnh] [-c .rcfile] [-V] [-T <format>]",pname);
- printf("\nBatch-mode scan:\n %s -q [-pPS] <host> <port> <user> <pass> <targets-file> <result-file>",pname);
- printf("\nList sessions  :\n %s -s -q <host> <port> <user> <pass> ",pname);
- printf("\nRestore session:\n %s -R <sessionid> -q <host> <port> <user> <pass> <result-file> ",pname);
+ printf(_("\nCommon options :\n %s [-vnh] [-c .rcfile] [-V] [-T <format>]"),pname);
+ printf(_("\nBatch-mode scan:\n %s -q [-pPS] <host> <port> <user> <pass> <targets-file> <result-file>"),pname);
+ printf(_("\nList sessions  :\n %s -s -q <host> <port> <user> <pass> "),pname);
+ printf(_("\nRestore session:\n %s -R <sessionid> -q <host> <port> <user> <pass> <result-file> "),pname);
 #else /* AF_UNIX */
- printf("\nBatch-mode scan:\n %s -q [-pPS] <user> <pass> <targets-file> <result-file>",pname);
- printf("\nList sessions  :\n %s -s -q <user> <pass> ",pname);
- printf("\nRestore session:\n %s -R <sessionid> -q <user> <pass> <result-file> ",pname);
+ printf(_("\nBatch-mode scan:\n %s -q [-pPS] <user> <pass> <targets-file> <result-file>"),pname);
+ printf(_("\nList sessions  :\n %s -s -q <user> <pass> "),pname);
+ printf(_("\nRestore session:\n %s -R <sessionid> -q <user> <pass> <result-file> "),pname);
 #endif
- printf("\nReport conversion :\n %s -i in.[nsr|nbe] -o out.[html|xml|nsr|nbe]\n\n", pname);
- printf("General options :\n");
- printf("\t-v : shows version number\n");
- printf("\t-h : shows this help\n"); 
- printf("\t-n : No pixmaps\n");
- printf("\t-T : Output format: 'nbe', 'html', 'html_graph', 'text', 'xml',\n");
+ printf(_("\nReport conversion :\n %s -i in.[nsr|nbe] -o out.[html|xml|nsr|nbe]\n\n"), pname);
+ printf(_("General options :\n"));
+ printf(_("\t-v : shows version number\n"));
+ printf(_("\t-h : shows this help\n")); 
+ printf(_("\t-n : No pixmaps\n"));
+ printf(_("\t-T : Output format: 'nbe', 'html', 'html_graph', 'text', 'xml',\n"));
  printf("\t    'old-xml' 'tex' or 'nsr'\n");
- printf("\t-V : make the batch mode display status messages\n");
- printf("\t    to the screen.\n");
- printf("\t-x : override SSL \"paranoia\" question preventing nessus from\n");
- printf("\t    checking certificates.\n\n");
- 
- printf("The batch mode (-q) arguments are :\n");
+ printf(_("\t-V : make the batch mode display status messages\n"
+          "\t    to the screen.\n"));
+ printf(_("\t-x : override SSL \"paranoia\" question preventing nessus from\n"
+          "\t    checking certificates.\n\n"));
+
+ printf(_("The batch mode (-q) arguments are :\n"));
 #ifdef USE_AF_INET
- printf("\thost     : nessusd host\n");
- printf("\tport     : nessusd host port\n");
+ printf(_("\thost     : nessusd host\n"));
+ printf(_("\tport     : nessusd host port\n"));
 #endif
- printf("\tuser     : user name\n");
- printf("\tpass     : password\n");
- printf("\ttargets  : file containing the list of targets\n");
- printf("\tresult   : name of the file where \n\t\t   nessus will store the results\n");
- printf("\t-p       : obtain list of plugins installed on the server.\n");
- printf("\t-P       : obtain list of server and plugin preferences.\n");
- printf("\t-S       : issue SQL output for -p and -P (experimental).\n");
+ printf(_("\tuser     : user name\n"));
+ printf(_("\tpass     : password\n"));
+ printf(_("\ttargets  : file containing the list of targets\n"));
+ printf(_("\tresult   : name of the file where \n\t\t   nessus will store the results\n"));
+ printf(_("\t-p       : obtain list of plugins installed on the server.\n"));
+ printf(_("\t-P       : obtain list of server and plugin preferences.\n"));
+ printf(_("\t-S       : issue SQL output for -p and -P (experimental).\n"));
  /* TODO: The following options are not described yet: -m  (jfs) */
 }
  
@@ -800,25 +776,28 @@ int main(int argc, char * argv[])
   int list_prefs  = 0;
   int sqlize_output = 0;
   int restore_session = 0;
+#ifdef ENABLE_SAVE_TESTS
   char * session_id = NULL;
+#endif
   char * arg = NULL;
   int opt_V= 0;
   int opt_i= 0;
   int opt_o= 0;
   char * inf = NULL, *outf = NULL;
 
+  /* Setup I18N. */
+  i18n_init();
+
   /*
    * Version check
    */
-   
- 
 
   if(version_check(NESSUS_VERSION, nessuslib_version())>0)
   {
    fprintf(stderr, 
-"Error : we are linked against nessus-libraries %s. \n\
+_("Error : we are linked against nessus-libraries %s. \n\
 Install nessus-libraries %s or make sure that\n\
-you have deleted older versions nessus libraries from your system\n",
+you have deleted older versions nessus libraries from your system\n"),
         nessuslib_version(), NESSUS_VERSION);
   }
 
@@ -833,11 +812,7 @@ you have deleted older versions nessus libraries from your system\n",
   else
     myself ++ ;
 
-  PluginsNum = 0;
-  ScannersNum = 0;
-  Scanners = Plugins = MainDialog = NULL;
-  ArgSock = NULL;
-  GlobalSocket = -1;
+  MainDialog = NULL;
 #ifdef USE_GTK
   F_quiet_mode = 0;
   F_show_pixmaps = 1;
@@ -939,12 +914,12 @@ you have deleted older versions nessus libraries from your system\n",
       	 opt_V++;
 	 break;
     case 'v' :
-    	printf("nessus (%s) %s for %s\n\n(C) 1998 - 2006 Tenable Network Security, Inc.\n", 
+    	printf("nessus (%s) %s for %s\n\n(C) 1998 - 2003 Renaud Deraison <deraison@nessus.org>\n", 
     			PROGNAME,NESSUS_VERSION, NESS_OS_NAME);
 #ifdef NESSUS_ON_SSL
-	printf("\tSSL used for client - server communication\n");
+	printf(_("\tSSL used for client - server communication\n"));
 #else
-	printf("\tclient - server communication is done in PLAIN TEXT\n");
+	printf(_("\tclient - server communication is done in PLAIN TEXT\n"));
 #endif					
 	printf ("\n");
     	exit(0);
@@ -988,11 +963,14 @@ you have deleted older versions nessus libraries from your system\n",
       exit (0);
     }
   }
-  
+
+  /* Initialize global context */
+  context_init(&Global, NULL);
+  Context = Global;
+
  if(opt_i || opt_o)
  {
   int be;
-  preferences_init(&Prefs);
   if(!(opt_i && opt_o))
    {
     display_help("nessus");
@@ -1032,7 +1010,7 @@ you have deleted older versions nessus libraries from your system\n",
    	backend_to_xml_ng(be, outf); 
    else
    	{
-	 fprintf(stderr, "Unsupported report type '%s'\n", type);
+	 fprintf(stderr, _("Unsupported report type '%s'\n"), type);
 	 exit(1);
 	 }
   backend_close(be);
@@ -1040,7 +1018,7 @@ you have deleted older versions nessus libraries from your system\n",
   }
   else
   {
-   fprintf(stderr, "Could not import '%s' - is it a .nsr or .nbe file ?\n",
+   fprintf(stderr, _("Could not import '%s' - is it a .nsr or .nbe file ?\n"),
    		inf);		
   }
   exit(0);
@@ -1063,19 +1041,19 @@ you have deleted older versions nessus libraries from your system\n",
 #ifdef ENABLE_SAVE_TESTS
  if(list_sessions && (argc<=optind) && !F_quiet_mode)
  {
-  fprintf(stderr, "list-sessions requires %s\n", BATCH_USAGE);
+  fprintf(stderr, _("list-sessions requires %s\n"), BATCH_USAGE);
   exit(1);
  }
  
  if(restore_session && (argc<=optind) && !F_quiet_mode)
  {
-  fprintf(stderr, "restore-session requires -q %s result\n", BATCH_USAGE);
+  fprintf(stderr, _("restore-session requires -q %s result\n"), BATCH_USAGE);
   exit(1);
  }
  
  if(restore_session && list_sessions)
  {
-  fprintf(stderr, "--restore-session and --list-sessions are mutually exclusive\n");
+  fprintf(stderr, _("--restore-session and --list-sessions are mutually exclusive\n"));
   exit(1);
  }
 #endif
@@ -1085,6 +1063,7 @@ you have deleted older versions nessus libraries from your system\n",
      {
       signal(SIGINT, sighand_exit);
       signal(SIGQUIT, sighand_exit);
+      signal(SIGKILL, sighand_exit);
       signal(SIGTERM, sighand_exit);
       
       F_quiet_mode = 1;
@@ -1095,20 +1074,24 @@ you have deleted older versions nessus libraries from your system\n",
       init_display (&argc, &argv);
      }
 #endif
-  
+
   /* system environment set up */
   if(!opt_m)
   {
-  if (preferences_init(&Prefs))
+    if (preferences_init(Global))
     exit (2);
- }
- else
-  Prefs = emalloc(sizeof(struct arglist));
+  }
+  else
+    Global->prefs = emalloc(sizeof(struct arglist));
 
+#ifdef USE_GTK
+  if(!F_quiet_mode)
+    context_collect(Global);
+#endif /* USE_GTK */
 
   if(opt_V && !F_quiet_mode)
   {
-	  fprintf(stderr, "Verbose mode can only be used in batch mode\n");
+	  fprintf(stderr, _("Verbose mode can only be used in batch mode\n"));
 	  exit(1);
   }
   
@@ -1142,14 +1125,14 @@ you have deleted older versions nessus libraries from your system\n",
  if(list_sessions || opt_m || list_plugins || list_prefs)
   {
   if (argc - optind != NUM_ARGS - 2) {
-      fprintf(stderr, "list-sessions only requires " BATCH_USAGE "\n");
+      fprintf(stderr, "%s" BATCH_USAGE "\n", _("list-sessions only requires "));
       exit(1);
     }
   }
   else if(restore_session)
   {
     if (argc - optind != NUM_ARGS - 1) {
-      fprintf(stderr, "restore-session only requires " BATCH_USAGE " <result-file>\n");
+      fprintf(stderr, "%s" BATCH_USAGE " <result-file>\n", _("restore-session only requires "));
       exit(1);
     }
   }
@@ -1185,10 +1168,9 @@ you have deleted older versions nessus libraries from your system\n",
 
     if(list_prefs)
     {
-     First_time = 0;
      if(cli_connect_to_nessusd(cli) < 0)
      {
-      fprintf(stderr, "Could not connect to nessusd\n");
+      fprintf(stderr, _("Could not connect to nessusd\n"));
       exit(1);
      }
     if(sqlize_output)
@@ -1200,10 +1182,9 @@ you have deleted older versions nessus libraries from your system\n",
     }
     if(list_plugins)
     {
-     First_time = 0;
      if(cli_connect_to_nessusd(cli) < 0)
       {
-       fprintf(stderr, "Could not connect to nessusd\n");
+       fprintf(stderr, _("Could not connect to nessusd\n"));
        exit(1);
        }
       if(sqlize_output)
@@ -1229,13 +1210,13 @@ you have deleted older versions nessus libraries from your system\n",
       char * t = argv[inc_optind()];
       if(t)cli_args_target(cli, t);
       else {
-	      fprintf(stderr, "Missing parameter\n");
+	      fprintf(stderr, _("Missing parameter\n"));
 	      display_help(myself);
       }
       t = argv[inc_optind()];
       if(t) cli_args_results(cli,  t);
       else {
-	      fprintf(stderr, "Missing parameter\n");
+	      fprintf(stderr, _("Missing parameter\n"));
 	      display_help(myself);
       }
      }
@@ -1251,12 +1232,12 @@ you have deleted older versions nessus libraries from your system\n",
     if(list_sessions){
     	cli_list_sessions(cli);
 #ifdef NESSUS_ON_SSL
-	close_stream_connection(GlobalSocket);
+	close_stream_connection(Context->socket);
 #else
-	shutdown(GlobalSocket,2);
-	closesocket(GlobalSocket);
+	shutdown(Context->socket ,2);
+	closesocket(Context->socket);
 #endif
-	GlobalSocket = -1;
+	Context->socket = -1;
 	nessus_exit(0);
 	}
     else if(restore_session) {
@@ -1265,8 +1246,8 @@ you have deleted older versions nessus libraries from your system\n",
    else	
 #endif    	
     if(opt_m){
-    	if(!preferences_generate_new_file())
-	 printf("A new nessusrc file has been saved\n");
+    	if(!preferences_generate_new_file(Global, NULL))
+	 printf(_("A new nessusrc file has been saved\n"));
 	}
     else
      {
@@ -1276,47 +1257,43 @@ you have deleted older versions nessus libraries from your system\n",
     /* end, exit */
     nessus_exit(0);
   }
- 
-  F_nessusd_running = 0;
-  
+
   /*
    * Set up the main window
    */
 
 #if 0
-  paranoia_level = arg_get_value(Prefs, "paranoia_level");
+  paranoia_level = prefs_get_int(context, "paranoia_level");
   if (paranoia_level == 0)
    
     {
         paranoia_level = sslui_ask_paranoia_level();
 	if(paranoia_level > 0)
- 	 arg_add_value(Prefs, "paranoia_level", ARG_INT, -1, (void*)paranoia_level);
+ 	 prefs_set_int(context, "paranoia_level", paranoia_level);
     }
 #endif    
 #ifdef USE_GTK
-  prefs_dialog_setup (NULL, Prefs);
-  /*
-   * all the options have been taken in account... Now, the user
-   * may want us to open a previously saved file
-   */
-  for (i = 1; i < xac; i ++) {
-    int be = backend_import_report(xav[i]);
-    if(be >= 0)
-     report_tests_ng (be, 0);
-   } 
-
+  prefs_dialog_setup(Global);
+  prefs_context_update(Global);
 
   gtk_main();
-  close_stream_connection(GlobalSocket);
-  close_display();
-  GlobalSocket = -1;
-  return(0);
+
+  /* XXX: Server preferences are not saved here */
+  prefs_dialog_apply(Context, MainDialog);
+  context_save_recurse(Global);
+
+  /* FIXME: close all open connections
+  close_stream_connection(Context->socket);
+  Context->socket = -1;
+  */
+  nessus_exit(0);
+  return 0; /* make the compiler happy */
 
 #else
-  printf("\nOoops ...\n\
+  printf(_("\nOoops ...\n\
   This nessus version has no gui support.  You need to give nessus the\n\
   arguments SERVER PORT LOGIN TRG RESULT as explained in more detail\n\
-  using the --help option.\n");
+  using the --help option.\n"));
   exit (1);
 #endif
 }
