@@ -192,6 +192,7 @@ preferences_new(context)
     fprintf(f, " cgi_path = /cgi-bin:/scripts\n");
     fprintf(f, " port_range = default\n");
     fprintf(f, " auto_enable_dependencies = yes\n");
+    fprintf(f, " silent_dependencies = yes\n");
     /* end of values from nessusd/preferences.c */
     fprintf(f, "end(SERVER_PREFS)\n");
   }
@@ -693,6 +694,12 @@ prefs_get_default(context, name)
     return pdfviewer;
   }
 #endif /* USE_GTK */
+  else if(!strcmp(name, "url_cve"))
+    return "http://cgi.nessus.org/cve.php3?cve=%s-%s-%s";
+  else if(!strcmp(name, "url_bid"))
+    return "http://cgi.nessus.org/bid.php3?bid=%s";
+  else if(!strcmp(name, "url_nessus"))
+    return "http://cgi.nessus.org/nessus_id.php3?id=%s";
   else if(!strcmp(name, "targets"))
     return "localhost";
   else if(!strcmp(name, "tree_autoexpand"))
@@ -709,7 +716,8 @@ prefs_get_value(context, name)
   void *value = arg_get_value(context->prefs, name);
   int type = arg_get_type(context->prefs, name);
 
-  if(type < 0 || (type != ARG_INT && value == NULL))
+  if(type < 0 || (type != ARG_INT && value == NULL)
+      || (type == ARG_STRING && !strlen((const char *)value)))
     value = prefs_get_default(context, name);
   return value;
 }
@@ -774,7 +782,11 @@ prefs_set_string(context, name, value)
   const char *name;
   const char *value;
 {
-  prefs_set_value(context, name, (void *)value, ARG_STRING);
+  const char *default_value = prefs_get_default(context, name);
+  if(!default_value || strcmp(value, default_value))
+    prefs_set_value(context, name, (void *)value, ARG_STRING);
+  else
+    prefs_set_value(context, name, (void *)"", ARG_STRING);
 }
 
 /* are there any options besides "name" and "comment"? */
