@@ -77,7 +77,10 @@ show_users_manual(menuitem, ctrls)
 #else
   char * dir = "";
 #endif
-  char * fname = "users-manual.pdf";
+  /* the pdf file is covered by gettext to allow
+   * speficication of translation in the respective po
+   * files rather than in the source code. */
+  char * fname = _("users-manual.pdf");
   char * path = g_build_filename(dir, fname, NULL);
 
   show_pdf(path);
@@ -663,6 +666,23 @@ prefs_dialog_set_defaults(context, ctrls)
     else
       GTK_TOGGLE_BUTTON(gtkw)->active = FALSE;
   }
+  gtkw = arg_get_value(t, "SILENT_DEPS");
+  if(gtkw)
+  {
+    v = arg_get_value(serv, "silent_dependencies");
+    if(arg_get_type(serv, "silent_dependencies") == ARG_INT)
+    {
+      char *s = strdup(v ? "yes" : "no");
+
+      arg_set_type(serv, "silent_dependencies", ARG_STRING);
+      arg_set_value(serv, "silent_dependencies", strlen(s), s);
+      v = s;
+    }
+    if(v && !strcmp(v, "yes"))
+      GTK_TOGGLE_BUTTON(gtkw)->active = TRUE;
+    else
+      GTK_TOGGLE_BUTTON(gtkw)->active = FALSE;
+  }
   /*
    *  Host expansion options
    */
@@ -921,6 +941,9 @@ prefs_dialog_set_tooltips(ctrls)
   w = arg_get_value(t, "ENABLE_DEPS_AT_RUNTIME");
   gtk_tooltips_set_tip(tooltips, w, HLP_ENABLE_DEPS_AT_RUNTIME, "");
 
+  w = arg_get_value(t, "SILENT_DEPS");
+  gtk_tooltips_set_tip(tooltips, w, HLP_SILENT_DEPS, "");
+
   t = arg_get_value(ctrls, "TARGET");
   w = arg_get_value(t, "DNS_EXPAND");
   gtk_tooltips_set_tip(tooltips, w, HLP_HOST_EXPANSION_DNS, "");
@@ -1014,6 +1037,21 @@ prefs_dialog_apply(context, ctrls)
       arg_add_value(serv, "auto_enable_dependencies", ARG_STRING, strlen(s),
 	  s);
   }
+  gtkw = arg_get_value(t, "SILENT_DEPS");
+  if(gtkw)
+  {
+    char *s;
+
+    if(GTK_TOGGLE_BUTTON(gtkw)->active)
+      s = estrdup("yes");
+    else
+      s = estrdup("no");
+
+    if(arg_get_value(serv, "silent_dependencies"))
+      arg_set_value(serv, "silent_dependencies", strlen(s), s);
+    else
+      arg_add_value(serv, "silent_dependencies", ARG_STRING, strlen(s), s);
+  }
 
 
 
