@@ -19,7 +19,10 @@
 #ifndef _NESSUSC_PREFS_DIALOG_H
 #define _NESSUSC_PREFS_DIALOG_H
 
-void prefs_dialog_setup(GtkWidget* , struct arglist *);
-int prefs_dialog_ok(GtkWidget * , struct arglist *);
-void prefs_dialog_set_defaults(struct arglist * , struct arglist *);
+#include "context.h"
+
+void prefs_dialog_setup(struct context *);
+void prefs_dialog_apply(struct context *, struct arglist *);
+int prefs_dialog_execute(GtkWidget *, struct arglist *);
+void prefs_dialog_set_defaults(struct context *, struct arglist *);
 #endif
