@@ -1,4 +1,4 @@
-/* $Id: prefs_dialog_auth.c,v 1.51 2004/12/14 08:04:40 thomas Exp $
+/* $Id: prefs_dialog_auth.c,v 1.52 2005/04/21 15:08:29 thomas Exp $
  *
  * Copyright (C) 2004 by Intevation GmbH
  * Author(s):
@@ -253,6 +253,13 @@ prefs_dialog_auth_do_connect(context, ctrls)
   label = gtk_label_new(text);
   gtk_widget_show(label);
   gtk_box_pack_start_defaults(GTK_BOX(vbox), label);
+
+  context->pbar = gtk_progress_bar_new();
+  gtk_progress_bar_set_text(GTK_PROGRESS_BAR(context->pbar),
+      _("Initiating connection ..."));
+  gtk_widget_show(context->pbar);
+  gtk_box_pack_start_defaults(GTK_BOX(vbox), context->pbar);
+
   gtk_widget_show(dialog);
   arg_set_value(ctrls, "CONTEXT", -1, dialog);
 
