@@ -31,10 +31,12 @@
 
 #ifdef USE_GTK
 #include <gtk/gtk.h>
-#include "../xstuff.h"
-#include "../preferences.h"
-#include "globals.h"
 
+#include "../nessus_i18n.h"
+
+/*
+ * XXX: this isn't used anywhere
+ */
 
 struct arglist * prefs_dialog_misc()
 {
@@ -46,7 +48,7 @@ struct arglist * prefs_dialog_misc()
  GtkWidget * label;
  struct arglist * ctrls = emalloc(sizeof(struct arglist));
  
- frame = gtk_frame_new("Misc.");
+ frame = gtk_frame_new(_("Misc."));
  gtk_container_border_width(GTK_CONTAINER(frame), 10);
  gtk_widget_show(frame);
  arg_add_value(ctrls, "FRAME", ARG_PTR, -1, frame);
@@ -60,7 +62,7 @@ struct arglist * prefs_dialog_misc()
  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
  gtk_widget_show(hbox);
  
- label = gtk_label_new("Max threads : ");
+ label = gtk_label_new(_("Max threads : "));
  gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
  gtk_widget_show(label);
  
@@ -69,7 +71,7 @@ struct arglist * prefs_dialog_misc()
  gtk_widget_show(max_threads);
  arg_add_value(ctrls, "MAX_THREADS", ARG_PTR, -1, max_threads);
  
- remember_plugin_set = gtk_check_button_new_with_label("Remember the set of plugins");
+ remember_plugin_set = gtk_check_button_new_with_label(_("Remember the set of plugins"));
  gtk_box_pack_start(GTK_BOX(vbox), remember_plugin_set, FALSE, FALSE, 0);
  gtk_widget_show(remember_plugin_set);
  arg_add_value(ctrls, "REMEMBER_PLUGIN_SET", ARG_PTR, -1, remember_plugin_set);
