@@ -231,4 +231,9 @@ _("If you enable this option, then Nessus Server \
 will enable the plugins that are depended on by the set of plugins you \
 selected.")
 
+#define HLP_SILENT_DEPS _("If you enable this option, then nessusd \
+will not report data coming from the plugins that you did not specifically \
+enable.")
+
+
 #endif
