@@ -51,51 +51,25 @@ static void prefs_family_toggle_callback(GtkWidget *, struct arglist *);
 static void prefs_plugin_list_toggle_callback(GtkWidget *, struct arglist *);
 static void prefs_plugin_list_callback(GtkWidget *, struct arglist *);
 static void prefs_family_list_callback(GtkWidget *, struct arglist *);
-static GtkWidget *warning_sign(GtkWidget *);
-
 
+/*
+ * Compare function used to sort plugin and their families.
+ */
 static int
-file_dialog_hide(filew, nul)
-  GtkWidget *filew;
-  GtkWidget *nul;
+glist_cmp(a, b)
+  gconstpointer a;
+  gconstpointer b;
 {
-  gtk_widget_hide(filew);
-  gtk_widget_destroy(filew);
-  return 0;
+  GtkWidget * item_a = (GtkWidget*)a;
+  GtkWidget * item_b = (GtkWidget*)b;
+
+  char * str_a, * str_b;
+
+  str_a = gtk_object_get_data(GTK_OBJECT(item_a), "list_item_data");
+  str_b = gtk_object_get_data(GTK_OBJECT(item_b), "list_item_data");
+  return strcmp(str_a, str_b);
 }
 
-static int
-file_selected(nul, filew)
-  GtkWidget *nul;
-  GtkWidget *filew;
-{
-  char *fname =
-      (char *)gtk_file_selection_get_filename(GTK_FILE_SELECTION(filew));
-  gtk_widget_hide(filew);
-
-  comm_plugin_upload(fname);
-  return 0;
-}
-
-
-static int
-hdl_plugin_upload(w, y)
-  GtkWidget *w;
-  GtkWidget *y;
-{
-  GtkWidget *filew = gtk_file_selection_new(_("Select file"));
-
-  gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(filew)->ok_button),
-      "clicked", (GtkSignalFunc) file_selected, filew);
-
-  gtk_signal_connect_object(GTK_OBJECT(GTK_FILE_SELECTION(filew)->
-	  cancel_button), "clicked", GTK_SIGNAL_FUNC(file_dialog_hide),
-      GTK_OBJECT(filew));
-  gtk_widget_show(filew);
-  return 0;
-}
-
-
 static int
 warning_expl()
 {
@@ -281,14 +255,6 @@ prefs_dialog_plugins(context)
 
   gtk_widget_show(button);
 
-
-  button = gtk_button_new_with_label(_("Upload plugin..."));
-  gtk_signal_connect(GTK_OBJECT(button),
-      "clicked", GTK_SIGNAL_FUNC(hdl_plugin_upload), ctrls);
-  gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
-  gtk_widget_show(button);
-
-
   hbox = gtk_hbox_new(FALSE, 5);
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 5);
   gtk_widget_show(hbox);
@@ -299,6 +265,11 @@ prefs_dialog_plugins(context)
   gtk_widget_show(button);
   arg_add_value(ctrls, "ENABLE_DEPS_AT_RUNTIME", ARG_PTR, -1, button);
 
+  button =
+      gtk_check_button_new_with_label(_("Silent dependencies"));
+  gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
+  gtk_widget_show(button);
+  arg_add_value(ctrls, "SILENT_DEPS", ARG_PTR, -1, button);
 
   button = gtk_button_new_with_mnemonic(_("Fi_lter..."));
   gtk_signal_connect(GTK_OBJECT(button),
@@ -496,6 +467,7 @@ prefs_family_list_callback(widget, ctrls)
     plugs = plugs->next;
   }
 
+  dlist = g_list_sort(dlist, glist_cmp);
   gtk_tooltips_enable(tooltips);
   gtk_list_append_items(GTK_LIST(list), dlist);
 }
@@ -584,6 +556,7 @@ fill_plugins_family(context, ctrls)
     lfamilies = lfamilies->next;
   }
 
+  dlist = g_list_sort(dlist, glist_cmp);
   gtk_tooltips_enable(tooltips);
   gtk_list_append_items(GTK_LIST(list), dlist);
   prefs_family_list_callback(list, ctrls);
