@@ -19,6 +19,8 @@
 #ifndef _NESSUSC_PREFS_PLUGINS_H
 #define _NESSUSC_PREFS_PLUGINS_H
 
-struct arglist *  prefs_dialog_plugins(GtkWidget*);
-int prefs_plugins_redraw(GtkWidget *, void *, struct arglist *);
+#include "context.h"
+
+struct arglist *prefs_dialog_plugins(struct context *);
+void fill_plugins_family(struct context *, struct arglist *);
 #endif
