@@ -1,5 +1,6 @@
 /* Nessus
  * Copyright (C) 1998 - 2001 Renaud Deraison
+ * Copyright (C) 2004 Intevation GmbH
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2,
@@ -29,54 +30,48 @@
  */
 
 #include <includes.h>
-#include "nsr_output.h"
+#include "nessus_i18n.h"
 #include "error_dialog.h"
-#include "globals.h"
+#include "context.h"
 #include "backend.h"
 #include "auth.h"
+#include "globals.h" /* for closesocket() */
 
 
 void
 nessus_exit(code)
- int code;
+  int code;
 {
- backend_clear_all();
- exit(code);
-}
-void 
-sighand_pipe()
-{
-#ifdef USE_GTK
-  if(!F_quiet_mode)
-   show_error_and_wait("Connection closed by the server (SIGPIPE caught)");
-  else
-#endif
-  fprintf(stderr, "Connection closed by the server (SIGPIPE caught)\n");  
+  backend_clear_all();
+  exit(code);
 }
 
+void
+sighand_pipe()
+{
+  Context->socket = -1;
+  show_error(_("Connection closed by the server (SIGPIPE caught)"));
+}
 
 void 
 sighand_alarm()
 {
-#ifdef USE_GTK
-  if(!F_quiet_mode)show_error_and_wait("Connection timed out");
-  else
-#endif
- fprintf(stderr, "Connection timed out\n");  
+  show_error(_("Connection timed out"));
 }
- 
+
 void sighand_exit()
 {
- if(GlobalSocket > 0)
- {
-   network_printf( "CLIENT <|> STOP_WHOLE_TEST <|> CLIENT\n");
+  /* FIXME: close all open connections */
+  if(Context->socket > 0)
+  {
+    network_printf( "CLIENT <|> STOP_WHOLE_TEST <|> CLIENT\n");
 #ifdef NESSUS_ON_SSL
-   close_stream_connection(GlobalSocket);
-#else   
-   shutdown(GlobalSocket, 2);
-   closesocket(GlobalSocket);
-#endif   
-   GlobalSocket = -1;
- }
- nessus_exit (1);
+    close_stream_connection(Context->socket);
+#else
+    shutdown(Context->socket, 2);
+    closesocket(Context->socket);
+#endif
+    Context->socket = -1;
+  }
+  nessus_exit(1);
 }
