@@ -19,8 +19,8 @@
 #ifndef _NESSUSC_XSTUFF_H
 #define _NESSUSC_XSTUFF_H
 
-int init_display(int *argc, char * argv[]);
-void close_display();
+int init_display(int *argc, char *** argv);
 int close_window(GtkWidget * , GtkWidget * );
 int delete_event(GtkWidget * nul, void * data);
+GtkWidget *make_pixmap(GtkWidget *, GdkColor *, char **);
 #endif
