@@ -86,7 +86,7 @@ static void
 attack_sigterm()
 {
  hosts_stop_all();
- wait_for_children();
+ wait_for_children1();
 }
 
 
@@ -182,7 +182,7 @@ launch_plugin(globals, sched, plugin, hostname, cur_plug, num_plugs, hostinfos,
   strncpy(name, plug_get_path(args), sizeof(name) - 1);
   name[sizeof(name) - 1 ] = '\0';
 
-  if(plug_get_launch(args) || 
+  if(plug_get_launch(args) != LAUNCH_DISABLED || 
      category == ACT_INIT ||
     (category == ACT_SETTINGS)) /* can we launch it ? */
   {
@@ -540,13 +540,13 @@ attack_network(globals)
   int  save_session= 0;  
   int continuous   = 0;
   int detached     = 0;
-  hargwalk *  hw;
-  harglst * files;
-  char * key;
   int return_code = 0;
   char * port_range;
   plugins_scheduler_t sched;
   int fork_retries = 0;
+  harglst * files;
+  hargwalk * hw;
+  char     * key;
 
   host_ip.s_addr = 0;
   preferences    = arg_get_value(globals, "preferences");
@@ -637,7 +637,7 @@ start_attack_network:
   /*
    * Initialization of the attack
    */
-  sched  = plugins_scheduler_init(plugins,  preferences_autoload_dependencies(preferences) ); 
+  sched  = plugins_scheduler_init(plugins,  preferences_autoload_dependencies(preferences), preferences_silent_dependencies(preferences) ); 
   
   
   hg_flags = preferences_get_host_expansion(preferences);
