@@ -564,7 +564,7 @@ void comm_setup_plugins( struct arglist * globals, char * list )
   if ( p == NULL ) return;
   if ( list == NULL ) list = "-1;";
 
-  if ( atoi(list) == -1 ) enable = 1;
+  if ( atoi(list) == -1 ) enable = LAUNCH_RUN;
   /* Disable every plugin */
   while( p->next != NULL )
     {
@@ -600,7 +600,7 @@ void comm_setup_plugins( struct arglist * globals, char * list )
        if ( id != 0 )
 	{
          p = get_plug_by_id(array, id, num_plugins);
-         if ( p != NULL ) plug_set_launch(p->value, 1);
+         if ( p != NULL ) plug_set_launch(p->value, LAUNCH_RUN);
 #ifdef DEBUG
 	 else printf("PLUGIN ID %d NOT FOUND!!!\n", id);
 #endif
