@@ -181,7 +181,7 @@ nes_plugin_add(folder, name, plugins, preferences)
   if( args != NULL )
   {
    prev_plugin = arg_get_value(plugins, name);
-   plug_set_launch(args, 0);
+   plug_set_launch(args, LAUNCH_DISABLED);
    if( prev_plugin == NULL )
           arg_add_value(plugins, name, ARG_ARGLIST, -1, args);
     else
