@@ -1,5 +1,5 @@
 /* Nessus
- * Copyright (C) 1998 - 2006 Tenable Network Security, Inc.
+ * Copyright (C) 1998 - 2004 Renaud Deraison
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2,
@@ -18,7 +18,7 @@
  * This very simply utility generates/checks a signature for a given file
  *
  *
- * $Id: nessus-check-signature.c,v 1.1.2.3 2006/01/30 20:56:55 renaud Exp $
+ * $Id: nessus-check-signature.c,v 1.2 2005/03/16 18:50:11 renaud Exp $
  */
 #include <includes.h>
 #ifdef HAVE_SSL
@@ -38,9 +38,9 @@ int generate_signature(char * filename)
  RSA * rsa = NULL;
  FILE * fp = fopen(NESSUSD_STATEDIR "/nessus_org.priv.pem", "r");
  unsigned char  * result;
- unsigned int len;
+ int len;
  int i;
- unsigned char md[SHA_DIGEST_LENGTH+1];
+ char md[SHA_DIGEST_LENGTH+1];
  int be_len;
 
  SHA_CTX ctx;
