@@ -1,5 +1,5 @@
 /* Nessus
- * Copyright (C) 1998 - 2006 Tenable Network Security, Inc.
+ * Copyright (C) 1998 - 2004 Renaud Deraison
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2,
@@ -14,7 +14,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: nessusd.c,v 1.236.2.7 2006/10/16 17:55:54 renaud Exp $
+ * $Id: nessusd.c,v 1.241 2005/05/09 00:53:14 renaud Exp $
  */
 
 #include <includes.h>
@@ -251,6 +251,7 @@ start_daemon_mode
     setvbuf(stdout, NULL, _IOLBF, 0);
     setvbuf(stderr, NULL, _IOLBF, 0);
 #endif
+    log_write ("Redirecting debugging output to %s\n", s);  
 }
 
 
@@ -765,6 +766,7 @@ main_loop()
       
       if(restart != 0) restart_nessusd(); 
 
+      wait_for_children1();
       /* prevent from an io table overflow attack against nessus */
       if (asciiaddr != 0) {
 	time_t now = time (0);
@@ -945,7 +947,7 @@ init_network(port, sock, addr)
    chmod(name, 0777);
 #endif 
 
-  if(listen(*sock, 10)==-1)
+  if(listen(*sock, 128)==-1)
     {
       fprintf(stderr, "listen() failed : %s\n", strerror(errno));      
       shutdown(*sock, 2);
@@ -1218,7 +1220,7 @@ you have deleted older versions of libnasl from your system\n",
 	  break;
 
 	case 'v' :
-	  print_error("nessusd (%s) %s for %s\n(C) 1998 - 2006 Tenable Network Security, Inc.\n\n", 
+	  print_error("nessusd (%s) %s for %s\n(C) 1998 - 2004 Renaud Deraison <deraison@nessus.org>\n\n", 
 		 PROGNAME,NESSUS_VERSION, NESS_OS_NAME);
 	  DO_EXIT(0);
 	  break;
