@@ -1,5 +1,5 @@
 /* Nessus
- * Copyright (C) 1998 - 2006 Tenable Network Security, Inc.
+ * Copyright (C) 1998 - 2004 Renaud Deraison
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2,
@@ -238,7 +238,7 @@ ntp_11_long_attack(globals, orig)
    else return -1;
   }
  plugin_set = arg_get_value(preferences, "plugin_set");
- if( !plugin_set )
+ if(!plugin_set || plugin_set[0] == '\0' )
  {
   plugin_set = emalloc(3);
   sprintf(plugin_set, "-1");
@@ -285,12 +285,12 @@ ntp_11_read_prefs(globals)
  struct arglist *  preferences = arg_get_value(globals, "preferences");
  int soc = (int)arg_get_value(globals, "global_socket");
  char * input;
- int input_sz = 1024*1024;
+ int input_sz = 65535;
  int n;
 
  input = emalloc(input_sz);
  for (;;) {
-   input[0] = '\0';
+   bzero(input, input_sz);
 #if defined NESSUS_ON_SSL && DEBUG_SSL > 2
    fprintf(stderr, "ntp_11_read_prefs > soc=%d\n", soc);
 #endif
@@ -390,6 +390,14 @@ ntp_11_rules(globals)
  char * buffer;
  int finished = 0;
  struct sockaddr_in * soca;
+
+ if(arg_get_type(globals, "saved_rules")<0)
+  arg_add_value(globals, "saved_rules", ARG_PTR, -1, rules_dup(rules));
+ else
+ {
+  rules_free(rules);
+  rules = rules_dup(arg_get_value(globals, "saved_rules"));
+ }
  
  buffer = emalloc(4096); 
  while(!finished)
@@ -975,18 +983,13 @@ ntp_1x_send_dependencies(globals)
    if(strlen(fname) + strlen(buf) + 6 > buf_size)
    {
     buf_size *= 2;
-    if(strlen(fname) + strlen(buf) + 6 > buf_size)
-    	buf_size = strlen(fname) + strlen(buf) + 6;
-
     buf = erealloc(buf, buf_size);
    }
    strncat(buf, fname, buf_size);
    strncat(buf, " <|> ", buf_size);
    deps = deps->next;
   }
-#if 0
   arg_free_all(d);
-#endif
   
   auth_printf(globals, "%s\n", buf);
    
