@@ -25,6 +25,7 @@
 #include "pluginscheduler.h"
 #include "pluginload.h"
 #include "pluginlaunch.h"
+#include "preferences.h"
 #include "log.h"
 
 
@@ -52,13 +53,13 @@ void plugin_set_running_state(plugins_scheduler_t shed, struct scheduler_plugin
 static unsigned int mkhash(char * name)
 {
   int i;
-  int h = 0;
+  unsigned int h = 0;
   
   for(i=0; name[i] != '\0' ;i++)
-   h = ((h * 128) + name[i]) % HASH_MAX;
+   h += name[i]; 
    
  
-  return h;
+  return h % HASH_MAX;
 }
 
 /*------------------------------------------------------------------------------*/
@@ -213,6 +214,7 @@ static void hash_link_destroy(struct hash * h)
   efree(&h->dependencies);
  }
 
+ efree(&h->dependencies_ptr);
  arg_free_all(h->plugin->required_ports);
  arg_free_all(h->plugin->required_udp_ports);
  arg_free_all(h->plugin->required_keys);
@@ -252,9 +254,11 @@ static int hash_add(struct hash * h, char * name, struct scheduler_plugin * plug
  int num_deps = 0;
  
  l->plugin = plugin;
+ l->plugin->parent_hash = l;
  l->name   = name;
  l->next = h[idx].next;
  h[idx].next = l;
+ l->dependencies_ptr = NULL;
  
  if( deps == NULL )
   l->dependencies = NULL;
@@ -305,6 +309,7 @@ static int hash_add(struct hash * h, char * name, struct scheduler_plugin * plug
 
 
 
+
 static struct hash * _hash_get(struct hash * h, char * name)
 {
  unsigned int idx = mkhash(name);
@@ -319,38 +324,37 @@ static struct hash * _hash_get(struct hash * h, char * name)
  return NULL;
 }
 
-static struct scheduler_plugin * hash_get(struct hash * h, char * name)
-{
- struct hash * l = _hash_get(h, name);
- if(  l == NULL )
-  return NULL;
- else
-  return l->plugin;
-}
 
-static char ** hash_get_ports(struct hash * h, char * name)
-{
- struct hash * l = _hash_get(h, name);
- if( l == NULL)
-  return NULL;
- else
-  return l->ports;
-}
-
-
-static char ** hash_get_deps(struct hash * h, char * name)
+static struct hash ** hash_get_deps_ptr(struct hash * h, char * name)
 {
  struct hash * l = _hash_get(h, name);
  
  if( l == NULL )
   return NULL;
  
- if( l->dependencies == NULL )
+ if( l->dependencies_ptr == NULL )
   return NULL;
  
- return l->dependencies;
+ return l->dependencies_ptr;
 }
 
+static void hash_fill_deps(struct hash * h, struct hash * l )
+{
+ int i, j = 0;
+ if ( l->num_deps != 0 )
+ {
+  l->dependencies_ptr = emalloc((1 + l->num_deps) * sizeof(struct hash*));
+  for ( i = 0 ; l->dependencies[i] ; i ++ )
+	{
+	struct hash * d = _hash_get(h, l->dependencies[i]);
+	if ( d != NULL )
+	 l->dependencies_ptr[j++] = d;
+        else
+          log_write("%s depends on %s which could not be found\n", l->plugin->arglist->name, l->dependencies[i]);
+	}
+   l->dependencies_ptr[j] = NULL;
+  }
+}
 
 /*----------------------------------------------------------------------*/
 
@@ -377,7 +381,7 @@ struct plist * pl_get(struct plist * list, char * name)
 
 void scheduler_mark_running_ports(plugins_scheduler_t sched, struct scheduler_plugin * plugin)
 {
- char ** ports = hash_get_ports(sched->hash, plugin->arglist->name);
+ char ** ports = plugin->parent_hash->ports;
  int i;
  
  if( ports == NULL )
@@ -408,9 +412,8 @@ void scheduler_rm_running_ports(plugins_scheduler_t sched, struct scheduler_plug
  char ** ports; 
  int i;
 
-
  
- ports = hash_get_ports(sched->hash, plugin->arglist->name);
+ ports = plugin->parent_hash->ports;
 
  
  if( ports == NULL )
@@ -489,19 +492,18 @@ void scheduler_plugin_best_score(plugins_scheduler_t sched, int *bscore, struct
 
 
 
-struct scheduler_plugin * plugin_next_unrun_dependencie(plugins_scheduler_t sched, char ** dependencies, int already_in_dependencie)
+struct scheduler_plugin * plugin_next_unrun_dependencie(plugins_scheduler_t sched, struct hash ** dependencies_ptr, int already_in_dependencie)
 {
- struct hash * h = sched->hash;
  int flag = 0;
  int counter = 0;
  int i;
  
- if(dependencies == NULL)
+ if(dependencies_ptr == NULL)
   return NULL;
   
- for(i=0;dependencies[i] != NULL;i++)
+ for(i=0;dependencies_ptr[i] != NULL;i++)
   {
-   struct scheduler_plugin * plugin = hash_get(h, dependencies[i]);
+   struct scheduler_plugin * plugin = dependencies_ptr[i]->plugin;
    if(plugin != NULL)
    {
     int state = plugin_get_running_state(plugin);
@@ -509,14 +511,14 @@ struct scheduler_plugin * plugin_next_unrun_dependencie(plugins_scheduler_t sche
     {
      case PLUGIN_STATUS_UNRUN :
      	{
-	char ** deps = hash_get_deps(h, plugin->arglist->name);
+	struct hash ** deps_ptr = dependencies_ptr[i]->dependencies_ptr;
 	struct scheduler_plugin * ret;
 	counter ++;
-	if(deps == NULL)
+	if(deps_ptr == NULL)
 	  return plugin;	
 	else
 	 {
-	 ret = plugin_next_unrun_dependencie(sched, deps, 1);
+	 ret = plugin_next_unrun_dependencie(sched, deps_ptr, 1);
 	 if(ret == NULL)
 		return plugin;
 	 else 
@@ -537,7 +539,6 @@ struct scheduler_plugin * plugin_next_unrun_dependencie(plugins_scheduler_t sche
     }
    }
   }
-  else fprintf(stderr, "%s could not be found\n", dependencies[i]);
  }
   
   if(flag == 0)
@@ -551,36 +552,44 @@ struct scheduler_plugin * plugin_next_unrun_dependencie(plugins_scheduler_t sche
 /*
  * Enables a plugin and its dependencies
  */
-static void enable_plugin_and_dependencies(plugins_scheduler_t shed, struct arglist * plugin, char * name)
+static void enable_plugin_and_dependencies(plugins_scheduler_t shed, struct arglist * plugin, char * name, int silent)
 {
- char ** deps;
+ struct hash ** deps_ptr;
  int i;
+ int status;
  
- deps = hash_get_deps(shed->hash, name);
+ if ( plugin == NULL ) return;
 
- plug_set_launch(plugin, 1);
- 
- if(deps != NULL)
+ deps_ptr = hash_get_deps_ptr(shed->hash, name);
+
+ status = plug_get_launch(plugin);
+ if ( status == LAUNCH_DISABLED )
  {
-   for(i=0;deps[i] != NULL;i++)
+  if ( silent == 0 )
+   plug_set_launch(plugin, LAUNCH_RUN);
+  else
+   plug_set_launch(plugin, LAUNCH_SILENT);
+ }
+ 
+ if(deps_ptr != NULL)
+ {
+   for(i=0;deps_ptr[i] != NULL;i++)
     {
      struct scheduler_plugin * p;
-     p = hash_get(shed->hash, deps[i]);
-     if( p != NULL )
-       enable_plugin_and_dependencies(shed, p->arglist->value, p->arglist->name);
-     else
-       log_write("'%s' depends on '%s' which could not be found\n", name, deps[i]);
+     p = deps_ptr[i]->plugin;
+     if ( p != NULL && p->arglist != NULL ) enable_plugin_and_dependencies(shed, p->arglist->value, p->arglist->name, silent);
     }
  }
 }
 
 /*---------------------------------------------------------------------------*/
 
-plugins_scheduler_t plugins_scheduler_init(struct arglist * plugins, int autoload)
+plugins_scheduler_t plugins_scheduler_init(struct arglist * plugins, int autoload, int silent_dependencies)
 {
  plugins_scheduler_t ret = emalloc(sizeof(*ret));
  struct arglist * arg;
  int i;
+ struct hash * l;
  
  
  
@@ -627,13 +636,22 @@ plugins_scheduler_t plugins_scheduler_init(struct arglist * plugins, int autoloa
   }
  
  
+ for ( i = 0 ; i < HASH_MAX ; i ++ )
+ {
+  l = &ret->hash[i];
+  while ( l != NULL ){
+	 hash_fill_deps(ret->hash, l);
+	 l = l->next;
+	}
+ }
+ 
  if(autoload != 0)
  {
  arg = plugins;
  while(arg->next != NULL)
   {
-   if(plug_get_launch(arg->value) != 0)
-   	enable_plugin_and_dependencies(ret, arg->value, arg->name);
+   if(plug_get_launch(arg->value) != LAUNCH_DISABLED)
+   	enable_plugin_and_dependencies(ret, arg->value, arg->name, silent_dependencies);
    arg = arg->next;
   }
  }
@@ -645,7 +663,7 @@ plugins_scheduler_t plugins_scheduler_init(struct arglist * plugins, int autoloa
   struct list * l = ret->list[i];
   while (l != NULL )
   {
-   if(plug_get_launch(l->plugin->arglist->value) == 0)
+   if(plug_get_launch(l->plugin->arglist->value) == LAUNCH_DISABLED)
    {
     struct list * old = l->next;
 
@@ -710,11 +728,11 @@ struct scheduler_plugin * plugins_scheduler_next(plugins_scheduler_t h)
   {
    case PLUGIN_STATUS_UNRUN:
     {
-    char ** deps = hash_get_deps(h->hash, l->plugin->arglist->name);
+    struct hash ** deps_ptr = l->plugin->parent_hash->dependencies_ptr;
     
-    if(deps != NULL)
+    if(deps_ptr != NULL)
     {
-     struct scheduler_plugin * p = plugin_next_unrun_dependencie(h, deps, 0);
+     struct scheduler_plugin * p = plugin_next_unrun_dependencie(h, deps_ptr, 0);
      
      switch((int)p)
      {
@@ -824,3 +842,6 @@ void plugins_scheduler_free(plugins_scheduler_t sched)
  	list_destroy(sched->list[i]);	
  efree(&sched);
 }
+
+
+
