@@ -109,6 +109,8 @@ int preferences_new(char * name)
  fprintf(fd, "safe_checks = yes\n");
  fprintf(fd, "\n\n# Automatically activate the plugins that are depended on\n");
  fprintf(fd, "auto_enable_dependencies = yes\n");
+ fprintf(fd, "\n\n# Do not echo data from plugins which have been automatically enabled\n");
+ fprintf(fd, "silent_dependencies = yes\n");
  fprintf(fd, "\n\n# Designate hosts by MAC address, not IP address (useful for DHCP networks)\n");
  fprintf(fd, "use_mac_addr = no\n");
  
@@ -894,6 +896,32 @@ preferences_detached_scan_email(preferences)
 }
 
 
+int
+preferences_silent_dependencies(preferences)
+ struct arglist * preferences;
+{
+ static int yes = -1;
+ char * pref;
+ 
+ if(!preferences)
+  {
+   yes = -1;
+   return -1;
+  }
+  
+  
+ if(yes >= 0)
+  return yes;
+  
+  
+ pref = arg_get_value(preferences, "silent_dependencies");
+ if(pref && !strcmp(pref, "yes"))
+   yes = 1;
+ else
+   yes = 0;
+
+ return yes;
+}
 
 
 #ifdef NESSUS_ON_SSL
@@ -935,4 +963,5 @@ preferences_reset_cache()
  preferences_delay_between_scans(NULL);
  preferences_detached_scan(NULL);
  preferences_detached_scan_email(NULL);
+ preferences_silent_dependencies(NULL);
 }
