@@ -210,7 +210,7 @@ get_active_plugins_number(plugins)
   if(plugins != NULL)
    while(plugins->next != NULL)
    {
-    if(plug_get_launch(plugins->value))num++;
+    if(plug_get_launch(plugins->value) != LAUNCH_DISABLED )num++;
     plugins = plugins->next;
    }
    
@@ -364,6 +364,8 @@ temp_file_name()
  	if(close(fd) < 0)
 	 perror("close ");
 	}
+ sprintf(ret, "%s/tmp", NESSUSD_STATEDIR);
+ mkdir(ret, 0700);
  sprintf(ret, "%s/tmp/tmp.%d-%d", NESSUSD_STATEDIR, getpid(), rand()%1024);
  fd = open(ret, O_RDONLY);
  } 
@@ -493,3 +495,14 @@ int set_linger(soc, linger)
  l.l_linger = linger;
  return setsockopt(soc, SOL_SOCKET, SO_LINGER, (void*)&l, sizeof(l));
 }
+
+
+void wait_for_children1()
+{
+ int e;
+ do
+   {
+     errno = 0;
+     e = waitpid(-1, NULL, WNOHANG);
+   } while ( e > 0 || errno == EINTR );
+}
